function clone (x, init)
	local r = {}
	for k, v in pairs( x ) do
		if type(v) == "table" then
			r[k] = clone (v)
		else  r[k] = v             
		end
	end
	if init then
		for k, v in pairs( init ) do
			r[k] = v
		end
	end
	setmetatable (r, getmetatable(x))
	return r
end


function copy (x)
	local r = {}
	for k, v in pairs( x ) do
		r[k] = v
	end
	setmetatable (r, getmetatable(x))
	return r
end


function show_table (table)
	for i, v in pairs( table ) do
		print (i, v)
	end
end


function dump_table (table, file)
	file:write ("{\n")
	for k, v in pairs( table ) do
		if type (v) == "number" then
			if type (k) == "string" then
				file:write (k.." = "..v..",\n")
			else
				file:write ("["..k.."] = "..v..",\n")
			end
		elseif type (v) == "string" then
			if type (k) == "string" then
				file:write (k.." = [["..v.."]],\n")
			else
				file:write ("["..k.."] = [["..v.."]],\n")
			end
		elseif type (v) == "table" then
			if type (k) == "string" then
				file:write (k.." = ")
			else	
				file:write ("["..k.."] = ")
			end
			dump_table (v, file)
			file:write (",\n")
		elseif type (v) == "boolean" then
			if v then
				file:write (k.." = true,\n")
			else
				file:write (k.." = false,\n")
			end
		end
	end
	file:write ("}")
end
PARSING_VERB_EXPECTED 	= 0
PARSING_UNKNOWN_WORD 	= 1
PARSING_UNDEFINED_IT 	= 2
PARSING_INVALID_AND		= 3
PARSING_OBJECT_MISSING	= 4
PARSING_UNDEFINED_ACTION = 5
PARSING_TOO_MANY_OBJECTS = 6
PARSING_UNDEFINED_AGAIN = 7
PARSING_GENERAL_ERROR = 8


function parse (text)
	text = string.gsub (text, ",", " and ")

	local state = 0
	local temp, verb, obj1, obj2, phrase
	local phrases = {}
	
	text = string.gsub (text, '%b""', function (s)
		table.insert (phrases, string.sub (s, 2, -2))
		return "#"
	end)
	
	for s in string.gfind (text, "%S+") do
		if state == 0 then
			obj1, obj2, phrase = nil, nil, nil
			verb = verbs:replace (s)
			if not verb then
				parsing_error (PARSING_VERB_EXPECTED, s)
				return
			end
			state = 1
		
		elseif state == 1 then
			temp = prepositions:replace (s)
			if temp then
				if not obj1 then
					obj1 = {prep = temp, nouns = {}}
				end
			else
				temp = nouns:replace (s)
				if temp then
					if not obj1 then
						obj1 = {nouns = {}}
					end
					table.insert (obj1.nouns, temp)
					state = 2
				else
					temp = special:replace (s)
					if temp == "it" then
						if not obj1 then
							obj1 = {}
						end
						if it then
							it.prep = obj1.prep
							obj1 = it
						else
							parsing_error (PARSING_UNDEFINED_IT)
							return
						end
						state = 2
					elseif temp == "then" or temp == "and" then
						post_parse (verb, obj1, obj2, phrase)
						state = 0
					
					elseif s == "#" then
						obj1 = nil
						phrase = phrases [1]
						table.remove (phrases, 1)
					
					else
						parsing_error (PARSING_UNKNOWN_WORD, s)
						return
					end
				end
			end
		
		elseif state == 2 then
			temp = prepositions:replace (s)
			if temp then
				obj2 = {prep = temp, nouns = {}}
				it = obj1
				state = 3
			else
				temp = nouns:replace (s)
				if temp then
					table.insert (obj1.nouns, temp)
				else
					temp = special:replace (s)
					if temp == "then" then
						post_parse (verb, obj1, obj2, phrase)
						it = obj1
						state = 0
					elseif temp == "and" then
						state = 4

					elseif s == "#" then
						if not obj1.nouns then
							obj1 = nil
						end
						phrase = phrases [1]
						table.remove (phrases, 1)
						
					else
						parsing_error (PARSING_UNKNOWN_WORD, s)
						return
					end
				end
			end
		
		elseif state == 3 then
			temp = nouns:replace (s)
			if temp then
				table.insert (obj2.nouns, temp)
			else
				temp = special:replace (s)
				if temp == "then" then
					post_parse (verb, obj1, obj2, phrase)
					it = obj1
					state = 0
				elseif temp == "it" then
					it.prep = obj2.prep
					obj2 = it
				elseif temp == "and" then
					state = 5
					
				elseif s == "#" then
					obj2 = nil
					phrase = phrases [1]
					table.remove (phrases, 1)
					
				else
					if prepositions:replace (s) then
					else
						parsing_error (PARSING_UNKNOWN_WORD, s)
						return
					end
				end
			end
		
		elseif state == 4 then
			temp = verbs:replace (s)
			if temp then
				post_parse (verb, obj1, obj2, phrase)
				it = obj1
				verb, obj1, obj2, phrase = temp
				state = 1
			else
				temp = nouns:replace (s)
				if temp then
					if not obj1.mult then
						obj1.mult = {}
					end
					table.insert (obj1.mult, {pos = table.getn (obj1.nouns), noun = temp})
					state = 2
				else
					temp = special:replace (s)
					if temp == "then" then
						
					else
						parsing_error (PARSING_INVALID_AND)
						return
					end
				end
			end
		
		elseif state == 5 then
			temp = verbs:replace (s)
			if temp then
				post_parse (verb, obj1, obj2, phrase)
				it = obj1
				verb, obj1, obj2, phrase = temp
				state = 1
			else
				temp = nouns:replace (s)
				if temp then
					if not obj2.mult then
						obj2.mult = {}
					end
					table.insert (obj2.mult, {pos = table.getn (obj2.nouns), noun = temp})
					state = 3
				else
					temp = special:replace (s)
					if temp == "then" then
						
					else
						parsing_error (PARSING_INVALID_AND)
						return
					end
				end
			end		
		
		
		elseif state == 6 then
		elseif state == 7 then
		end
	end
	
	it = obj1

	if obj2 and table.getn (obj2.nouns) == 0 then
		parsing_error (PARSING_GENERAL_ERROR)
		return
	end
	
	post_parse (verb, obj1, obj2, phrase)
end


function find_object (name)
	if table.getn (name) == 0 then
		return {player}
	end

	local next, objects = player.parent
	repeat
		objects = next:find (name)
		if next.parent then
			next = next.parent
		end
	until table.getn (objects) ~= 0 or next.parent ~= world
	
	if table.getn(objects) > 1 then
		for i, obj in ipairs(objects) do
			if obj:isme(name) then return {obj} end
		end
	end
	
	return objects
end


function post_parse (verb, obj1, obj2, phrase)
	if verb == "again" and not obj1 and not obj2 and not phrase then
		if not parsed_again then
			parsing_error (PARSING_UNDEFINED_AGAIN)			
			return
		end
		
		parsing_again = true
		post_parse (parsed_again[1], parsed_again[2], parsed_again[3], parsed_again[4])
		parsing_again = false
		return
	end
	if not parsing_again then
		parsed_again = {verb, obj1, obj2, phrase}
	end
	
	if obj1 and obj1.mult then
		local mult = obj1.mult
		obj1.mult = nil
		post_parse (verb, obj1, obj2, phrase)
		for i, p in ipairs (mult) do
			obj1.nouns [p.pos], p.noun = p.noun, obj1.nouns [p.pos]
			post_parse (verb, obj1, obj2, phrase)
		end
		obj1.mult = mult
		return
	end

	if obj2 and obj2.mult then
		local mult = obj2.mult
		obj2.mult = nil
		post_parse (verb, obj1, obj2, phrase)
		for i, p in ipairs (mult) do
			obj2.nouns [p.pos], p.noun = p.noun, obj2.nouns [p.pos]
			post_parse (verb, obj1, obj2, phrase)
		end
		obj2.mult = mult
		return
	end

	if obj1 then
		obj1.object = nil
		if obj2 then
			obj2.object = nil
		end
		local objects
		
		local all = false
		if obj1 and obj1.nouns [1] == "all" then
			all = true
		end
		
		objects = find_object (obj1.nouns)
		if table.getn (objects) == 1 then
			obj1.object = objects [1]
		
		elseif  all and table.getn (objects) > 0 then
			if obj2 and not obj2.object then
				local objects = find_object (obj2.nouns)
				if table.getn (objects) == 1 then
					obj2.object = objects [1]
				end
			end
			
			for i, obj in ipairs (objects) do
				obj1.object = obj
				do_parsed (verb, obj1, obj2, phrase)
			end
			return
			
		elseif not obj2 then
				local name1, name2 = clone (obj1.nouns), {}
				for i=1, table.getn (name1) do
					objects = find_object (name1)
					if table.getn (objects) == 1 then
						obj1.object = objects [1]
						obj2 = {nouns = clone (name2)}
						objects = find_object (name2)
						if table.getn (objects) == 1 then
							obj2 = {nouns = name2, object = objects [1]}
							obj1.nouns = name1
							break
						end
					end
					table.insert (name2, name1 [table.getn (name1)])
					table.remove (name1)
				end
		end
			
		if not obj1.object then
			objects = find_object (obj1.nouns)
			if table.getn(objects) == 0 then
				parsing_error (PARSING_OBJECT_MISSING, table.concat (obj1.nouns, " "))
			else
				parsing_error (PARSING_TOO_MANY_OBJECTS, objects)
			end
			return
		end
		
		if obj2 and not obj2.object then
			objects = find_object (obj2.nouns)
			if table.getn (objects) == 1 then
				obj2.object = objects [1]
			else
				obj2.objects = objects
			end
		end
	end
	
	do_parsed (verb, obj1, obj2, phrase)
end


function do_parsed (verb, obj1, obj2, phrase)
	local event, object = {prep = {}}, player
	event.verb = verb
	event.default = true
	if obj2 then
		event.prep [2] = obj2.prep
		event.name = obj2.nouns
		event.object = obj2.object
		event.objects = obj2.objects
	end
	
	if obj1 then
		event.prep [1] = obj1.prep
		event.default = nil
		object = obj1.object
	end
	
	if phrase then
		event.phrase = phrase
	end
	
	local next, hevent = object, copy (event)
	hevent.verb = verb
	hevent.target = object
	hevent.before = true
	repeat
		if next.hooks then
			for i=1,table.getn (next.hooks) do
				if not next.hooks [i] (hevent) then
					return
				end
			end
		end
		
		next = next.parent
	until not next
	
	if object [verb] then
		if type(object[verb]) == "function" then
			object [verb] (object, event)
		else
			print (object [verb])
		end
	else
		parsing_error (PARSING_UNDEFINED_ACTION, {verb, object.name})
		return
	end

	hevent.before = nil
	hevent.after = true
	next = object
	repeat
		if next.hooks then
			for i=1,table.getn (next.hooks) do
				next.hooks [i] (hevent)
			end
		end
		
		next = next.parent
	until not next
end


function parsing_error (err, detail)
	if err == PARSING_VERB_EXPECTED then
		print ("error: unknown verb '"..detail.."'")
	elseif err == PARSING_UNKNOWN_WORD then
		print ("error: unknown word '"..detail.."'")
	elseif err == PARSING_UNDEFINED_IT then
		print "error: undefined 'it'"
	elseif err == PARSING_INVALID_AND then
		print "error: invalid using of 'and'"
	elseif err == PARSING_OBJECT_MISSING then
		print ("error: couldn't find object '"..detail.."'")
	elseif err == PARSING_UNDEFINED_ACTION then
		print ("error: undefined action '"..detail [1].."' of object '"..detail [2].."'" )
	elseif err == PARSING_TOO_MANY_OBJECTS then
		print "error: too many objects on the scene:"
		for i, v in ipairs( detail ) do
			print (v.name)
		end
	elseif err == PARSING_UNDEFINED_AGAIN then
		print "error: undefined again"
	elseif err == PARSING_GENERAL_ERROR then
		print "error: syntax error"

	end
end

--=================================================================================================
vocabulary = {}


function vocabulary:add (template)
	if type (template) == "table" then		
		table.insert (self, template)
	else
		if string.sub (template, -1) ~= "\n" then
			template = template.."\n"
		end

		local templ 
		for s in string.gfind (template, "(.-)\n") do
			templ = {}
			for s in string.gfind (s, "%S+") do
				table.insert (templ, s)
			end
			self:add (templ)
		end
	end
end


function vocabulary:replace (word)
	local left, right
	for i, template in ipairs (self) do
		for i, t in ipairs (template) do
			left, right = false, false
			if string.sub (t, 1, 1) == "*" then
				left = true
				t = string.sub (t, 2)
			end
			if string.sub (t, -1) == "*" then
				right = true
				t = string.sub (t, 1, -2)
			end
			
			if left and right then
				if string.find (word, t) then
					return template[1]
				end
			elseif left then
				if t == string.sub (word, -string.len (t)) then
					return template[1]
				end
			elseif right then
				if t == string.sub (word, 1, string.len(t)) then
					return template[1]
				end
			else
				if word == t then
					return template[1]
				end
			end
		end
	end
end


function vocabulary:check ()
	for i, template in ipairs (self) do
		for j, t in ipairs (template) do
			t = string.gsub (t, "*", "")
			if t ~= self:checking_replace (t, i) then
				print ("error in word "..template[1]..": it replaces by "..self:checking_replace(t, i))
			end
		end
	end
end



function vocabulary:checking_replace (word, line)
	local left, right
	for i, template in ipairs (self) do
		if i ~= line then
			for i, t in ipairs (template) do
				left, right = false, false
				if string.sub (t, 1, 1) == "*" then
					left = true
					t = string.sub (t, 2)
				end
				if string.sub (t, -1) == "*" then
					right = true
					t = string.sub (t, 1, -2)
				end
				
				if left and right then
					if string.find (word, t) then
						return template[1]
					end
				elseif left then
					if t == string.sub (word, -string.len (t)) then
						return template[1]
					end
				elseif right then
					if t == string.sub (word, 1, string.len(t)) then
						return template[1]
					end
				else
					if word == t then
						return template[1]
					end
				end
			end
		end
	end
	return word
end


--=================================================================================================
verbs = clone (vocabulary)

-- vocabulary
verbs:add [[
again     
look  * 
inventory   inv  i 
exit    goto
enter  
help   rules
startgame  start
quit bye   
stand   
clean tidy
up   
down  
climb    **
lie  
restart  
spusk    
think **
factos  * 
remember **
smoke *
smell **
open *
turnon *
read * *
elaborate  
east  
west  
north  
south  
southeast - 
northwest - 
northeast - 
southwest - 
exits  
let 
take  *
lisn ** listen
katch * **
turnof *
repare **
speak * *
study   
pobeg *
zasun    
peek *
touch * **
brek * * 
unlok   
wakeup * * 
ask *
what     
pute   put  
wrait * *
skey asx
burn * *
eat   
clous   
dropp *    *
putdown **
podbrosit *
test 
sdvin     
tuurn * * *
slozhit     
razlozhit    
]]
-- /vocabulary

verbs:check ()
nouns = clone (vocabulary)

-- vocabulary
nouns:add [[
all    
room * *  
stol table desk bureau *
floor     *
door *
my     
okno window     
myself      
first 
fork *
robot *
kopf *
tabur *
instrum * *
wall *
patch  *
potolok  *
spichka *
eyes *
mouth    
zub * *
dust   
hand   
sink * *
nos *
skaf *
delat 
naverx * *
surfac *
shelf * *
slit * * *
voice 
device * 
zhurn *
papka   * * folder
boks *
molotok *
speaker * * *
bell *
radio 
kluch *
bottle *
maska *
knob * * *
udilo * * *
]]
-- /vocabulary

nouns:check ()
prepositions = clone (vocabulary)

-- vocabulary
prepositions:add [[
in 
on at 
to 
into  
behind 
from 
with  
between 
about    *
the an a
under 
around 
through  via 
up  
down 
near   
]]
-- /vocabulary

prepositions:check ()
special = clone (vocabulary)

special:add [[
and 
then  
it her him            them 
]]

special:check ()
slib = {
	lang = { }
}

setmetatable(slib, {
	__index = function( self, key )
		return slib : get(key)
	end,
})

-- ============================================================================
-- collection to inherit

slib.collection = {
	__call = function(self, ...)
		if table.getn(self) == 0 then return end
		if self.rnd == true then
			local last = self.it
			if not last or table.getn(self) > 1 then
				self.it = last
				while self.it == last do
					self.it = math.random(table.getn(self))
				end
			else
				self.it = math.random(table.getn(self))
			end
		else
			self.it = self.it or 1
		end
		local text
		if table.getn(arg) > 0 then
			text = string.format(self[self.it], unpack(arg))
		else
			text = self[self.it]
		end
		if not self.rnd then
			self.it = math.mod(self.it, table.getn(self)) + 1
		end
		--print "\n"
		return text
	end,
}

-- ============================================================================
-- add new language library

function slib : add( language, library )
	assert(type(language)=="string" and type(library)=="string", "wrong arguments")
	library = string.gsub(library, "\\\n", "\r")
	
	local lib, it = { }
	string.gsub(library .. "\n", "(.-)\n", function( s )
		local green = false
		string.gsub(s, "%[([#]*)([%w.]+)%]", function( random, addr )
			it, green = lib, true
			string.gsub(addr, "%w+", function( name )
				if it[name] then
					it = it[name]
				else
					local coll = { rnd = (string.len(random) ~= 0) }
					setmetatable(coll, self.collection)
					it, it[name] = coll, coll
				end
			end)
		end)
		
		if not green and it then
			string.gsub(s, "%s*(%S.-)%s*$", function( phrase )
				phrase = string.gsub(phrase, "\r", "\n")
				table.insert(it, phrase)
			end)
		end
	end)
	
	self.lang[language] = lib
end

-- ============================================================================
-- set current language

function slib : set( language )
	assert(self.lang[language], "language " .. language .. " is missing in the library")
	self.current = language
end

-- ============================================================================
-- get top-level phrase by id (current language used)

function slib : get( id )
	assert(self.current, "the current language isn't set")
	local phrase = self.lang[self.current][id]
	assert(phrase, string.format("unknown phrase %q in %q ", id, self.current))
	return phrase
end

function slib : has( id )
	local phrase = self.lang[self.current][id]
	return phrase ~= nil
end

-- ============================================================================

local ru = [[

[player.desc.generic]
   .

[climbed.reveal1]
      %s.
   %s.

[climbed.reveal2]
    %s.

[climb.down.hardcase]
  o %s.

[climb.down.softcase]
   %s.

[climb.down.nogo]
    %s.

[climb.descitem.masc]
(  %s   .)
(       %s.)

[climb.descitem.fem]
(  %s   .)
(       %s.)

[climb.descitem.neut]
(  %s   .)
(       %s.)

[player.brek.nogo]
    .

[testfound]
 %s

[kluch.caption]

 

[kluch.gecaption]

 

[kluch.capcaption]

 

[kluch.precaption]
 


[kluch.utilcaption]

 

[kluch.accaption]

 

[capcaption.generic]


[caption.generic]


[accaption.generic]


[gecaption.generic]


[utilcaption.generic]


[precaption.generic]


[kluch.look.generic]
 ,  ,   .

[kluch.look.onskaf]
      .

[kluch.look.onskaf.high]
   ,  .   ,     .

[look.generic]
   .
     .
  -  .
   ,    .

[itemat.generic]
   %s.

[hason.make.fem]
   
 

[item.ison]
 %s

[item.isin]
 %s

[item.isunder]
 %s

[item.isat]
 %s
 %s

[hason.make.meut]
  

[item.idle.generic]



[itemon.generic1.desc1]
 %s
  %s

[itemon.generic1.desc2]
 %s.
 %s.

[itemon.generic2.desc1]
  %s
  %s

[itemon.generic2.desc2]
 %s.
 %s

[itembehind.generic1.desc1]
 %s
  %s

[itembehind.generic1.desc2]
 %s.
 %s.

[itembehind.generic2.desc1]
  %s
  %s

[itembehind.generic2.desc2]
 %s.
 %s

[itemin.generic1.desc1]
 %s

[itemin.generic1.desc2]
 %s.
 %s.
 %s.

[itemin.generic2.desc1]
  %s
 %s

[itemin.generic2.desc2]
 %s.
 %s.
 %s.

[floor.one]
   %s.
   %s.

[ground.one]
    %s.
   %s.

[water.one]
    %s.
    %s.

[floor.many]
   : 

[ground.many]
   
   

[water.many]
    

[floor.one.onsurface1]
 %s 

[floor.one.onsurface1]
 %s.

[look.obscured]
   ,    .
  ,      .

[lookunder.first]
   %s
  %s

[lookbehind.first]
   %s
  %s

[lookbehind.empty]
,     .
,    .

[lookbehind.single]
,  ,   
,  ,   
,   

[lookunder.mult]
;  
,  ,   
,   

[lookunder.second]
    %s
   %s

[lookunder.nothing.first]
,    .
,  ,    .
,  ,    .

[lookunder.nothing.second]
,      .
,  ,    .
,     .

[lookunder.single]
,  ,   
,  ,   
,   

[lookunder.mult]
;  
,  ,   
,   

[pol.look.generic]
 .

[lookbehind.whoputit.masc]
    .
   .

[lookbehind.whoputit.fem]
    .
   .

[putbehind.toomuch.one]
 %s    ,     .

[putbehind.toomuch.two]
 %s     .

[putbehind.nogo]
 %s    .
  %s  .

[bell.capcaption]


[bell.caption]

 

[bell.accaption]

 

[bell.precaption]

 

[bell.gecaption]

 

[radio.capcaption]



[radio.caption]



[radio.gepcaption]



[radio.accaption]



[radio.prepcaption]



[radio.utilpcaption]



[stol.capcaption]


[stol.caption]


[stol.accaption]


[stol.precaption]


[stol.gecaption]


[stol.utilcaption]


[boks.capcaption]

 

[boks.caption]

 

[boks.precaption]

 

[boks.accaption]

 

[boks.gecaption]

 

[boks.utilcaption]

 

[molotok.capcaption]


[molotok.caption]


[molotok.precaption]


[molotok.accaption]


[molotok.gecaption]


[molotok.utilcaption]


[maska.caption]


[maska.capcaption]

 

[maska.gecaption]

 

[maska.precaption]

 

[maska.utilcaption]

 

[maska.accaption]

 

[skaf.caption]

 

[skaf.precaption]

 

[skaf.accaption]

 

[skaf.gecaption]

 

[skaf.utilcaption]

 

[skaf.capcaption]


[fork.capcaption]

 

[fork.caption]

 

[fork.precaption]

 

[fork.accaption]

 

[fork.gecaption]

 

[fork.utilcaption]

 

[okno.caption]


[okno.precaption]


[okno.accaption]


[okno.gecaption]


[okno.utilcaption]


[boks.inside.one]
   %s.
   %s.

[boks.inside.many]
   %s
   %s

[skaf.inside.one]
   %s.
   %s.

[skaf.inside.many]
   %s.
   %s.

[stol.locdesc.generic]
   
    

[stol.look.generic]
   , ,  

[stol.surface.one.desc]
    %s.

[stol.surface.many]
   : 

[boks.locdesc.generic]
    

[boks.locdesc.onstol]
    .

[boks.locdesc.inhands]
     . 

[boks.locdesc.onskaf]
    .

[boks.look.generic]
     .

[bottle.caption]


[bottle.capcaption]


[bottle.gecaption]


[bottle.precaption]


[bottle.utilcaption]


[bottle.accaption]


[bottle.notake]
   ,   .

[bottle.alreadytake]
     .
    .

[bottle.desc.skaf.opened]
,   ,  - ,  .     .

[bottle.desc.skaf.closed]
,    ,   ,  .    .

[bottle.desc.elsewhere]
     .       .

[molotok.look.generic]
    .

[molotok.locdesc.generic]
    

[skaf.look.generic]
 -,    . <stop>   .

[skaf.locdesc.generic]
     
       

[skaf.desc.sdvinut]
    ,     .

[skaf.desc.nesdvinut]
     .
-      .

[skaf.kluch.vidno]
  ,  ,         .

[skaf.kluch.sled]
         .

[skaf.predescontain.closed]
   
  

[skaf.predescontain.opened]
   
  

[skaf.descontain1]
    -.

[skaf.descontain2]
 - .

[skaf.descontain3]
 .

[skaf.descontain4]
 - . 

[skaf.descontain5]
  .

[skaf.sdvig.nogo]
    ,   - .

[skaf.sdvigback1]
   <stop>         .

[skaf.sdvigback2]
    ,   .

[skaf.sdvigleft1]
,     . 

[skaf.sdvigleft.seeradio]
,    ... <stop><br>           .

[radio.hidden]
     .
    .

[radio.concealed.working]
  ,      ,  . 

[radio.concealed.broadcast]
-    ,  ..

[radio.concealed.broadcast.text1]
...   -.
..  .. 
..    ..
... --...

[radio.concealed.broadcast.text2]
... --.. !
....
..    !

[radio.concealed.broadcast.text3]

[radio.concealed.broadcast.text4]

[radio.concealed.broadcast.dtext4]
... -...
...  ,  ...
..     ...
.. ...

[radio.concealed.silent]
  ,    -   . 

[radio.behindmask.working]
   .

[radio.behindmask.saying]
, ,   ...  .    .
-,   , , ...  !  .

[radio.behindmask.silent]
     ,     ,       .

[radio.opened.working]
  .     .

[radio.opened.silent.notseen]
-         .

[radio.opened.silent.look]
,   ,     .    ,  -   .       .

[radio.opened.silent.seen]
 ,     , -  .

[fork.look.generic]
 .

[fork.locdesc.generic]
    

[okno.look.generic]
,       ,          - .
   ,    .
 ,     .

[okno.look.first]
   ... <stop><br>    .<stop><clear>         .

[okno.locdesc.generic]
       
    

[lookunder.generic]
 .
   %s,    - . ,   .

[touch.generic]
   %s. <br> .

[slib.box.surfac.empty]
  %s  .
 %s .

[boks.surface.one.desc1]
  %s 

[boks.surface.one.desc2]
 %s.
 %s.

[locdesc.generic]
    %s
   %s

[roomlook.hands]
    %s.

[item.hidden]
    %s.
   %s.

[open.item.novalid1]
 %s
 %s

[open.item.novalid2]
  %s  .
  %s  .

[open.item.unavailable1]
     %s,
     %s,
   ,  ,     %s,

[open.item.unavailable2]
   %s.

[open.item.around1]
  %s

[open.item.around2]
  %s,

[open.item.around3]
   %s  .

[lookon.item1]
 %s

[lookon.item2]
  %s
 %s

[lookin.item1]
 %s

[lookin.item2]
 %s

[lookbehind.obscured]
     
     

[lookbehind.item]
 %s

[lookunder.item]
 %s

[objekt.concealed]
     .

[item.inside.one.desc1]
 %s 
 ,   %s 

[item.inside.one.desc2]
 %s.
 %s.

[item.inside.many]
 %s   
 %s 

[item.onside.many]
 %s   
 %s 

[item.onside.one.desc1]
 %s 
 %s 
 ,   %s 

[item.onside.one.desc2]
 %s.
 %s.

[container.closed.fem]
 .
   %s .
 %s .

[container.closed.masc]
 .
   %s .
 %s .

[container.closed.neut]
 .
   %s .
 %s .

[container.open.fem]
 .
   %s .
 %s .

[container.open.masc]
 .
   %s .
 %s .

[container.open.neut]
 .
   %s .
 %s .

[takefrom.ground1.fem]
  %s,   .
  %s,   .


[takeitemon.begin]
  %s

[takeitemin.begin]
  %s
  %s
  %s

[takeitemunder.begin]
  %s
  %s
  %s

[takeitembehind.begin]
  %s
  %s

[takeitem.from.hardcase]
 %s

[takeitem.from.softcase]
 %s

[takeitem.from.container]
 %s

[takeitem.fromunder]
- %s

[takeitem.frombehind]
- %s

[putitem.room.fem]
  %s,  

[putitem.room.masc]
  %s,  

[putitem.room.neut]
  %s,  

[putitem.room.fin.fem]
   
    

[putitem.room.fin.masc]
   
    

[putitem.fromhands.fin.masc]
   
    

[putitem.fromhands.fin.fem]
  
   

[putitem.fin.prepon]
 %s

[putitem.fin.prepin]
 %s

[container.sayclosed.neut]
    .

[container.sayclosed.fem]
    .

[container.sayclosed.masc]
    .

[putitem.contopen.fem]
(  )
(     )

[putitem.contopen.masc]
(  )
(     )

[putitem.contopen.neut]
(  )
(    )

[putitem.fin.prepbehind]
 %s

[putitem.fin.prepunder]
 %s

[putitem.fin.prepat]
 %s

[puton.ground]
 

[puton.floor]
 


[putitem.floor.fem]
  %s,    , 

[putitem.floor.masc]
  %s,    , 

[putitem.floor.neut]
  %s,    , 

[putin.object_locked.fem]
%s ,   .
%s ,       .

[putin.object_locked.masc]
%s ,   .
%s ,       .

[putin.object_locked.neut]
%s ,   .
%s ,       .

[putin.object_toobig.masc]
%s  ,

[putin.object_toobig.fem]
%s  ,

[putin.object_toobig.neut]
%s  ,

[putin.object_toobig.fin.fem]
%s    .

[putin.object_toobig.fin.neut]
%s    .

[putin.object_hidden]
,      %s,    .
    ,      %s.

[putin.negate1]
    %s
   
 %s

[putin.negate2]
 %s.
 %s.
 %s   .

[putitem.karman.fem]
  %s,   , 
    %s, 
  %s,      , 

[putitem.karman.masc]
  %s,   , 
    %s, 
  %s,     , 

[putitem.karman.neut]
  %s,     , 
  %s,   , 
    %s, 

[putitem.karman.fin]
   %s.
    %s.

[putverb.klast]


[putverb.zasun]


[putverb.hide]


[putitemfrom.hands]
  %s
   %s

[putitemon.hands2]
  %s,    .
  %s.    .

[putitemin.hands2]
  %s,    .
  %s.    .

[putitemunder.hands2]
  %s,    .
  %s.    .

[putitembehind.hands2]
  %s,    .
  %s.    .

[putitemat.hands2]
  %s,    .
  %s.    .

[holditem.hands.fem]
    
       
    

[holditem.hands.masc]
    
       
     

[holditem.hands.neut]
, ,    
       
     

[holditem.karman.fem]
    
       
    

[holditem.karman.masc]
    
       
     

[holditem.karman.neut]
, ,    
       
     



[holditem.karman]
%s     .
%s     .

[putitemon.objtoohigh.fem]
  ,  %s , 
 ,  %s , 

[putitemon.objtoohigh.masc]
  ,  %s , 
 ,  %s , 

[putitemon.objtoohigh.neut]
  ,  %s , 
 ,  %s , 

[putitemon.objtoohigh2.fem]
    %s  .
    %s  .   .

[putitemon.objtoohigh2.masc]
    %s  .
    %s  .   .

[putitemon.objtoolow.fem]
  ,  %s , 
 ,  %s , 

[putitemon.objtoolow.masc]
  ,  %s , 
 ,  %s , 

[putitemon.objtoolow.neut]
  ,  %s , 
 ,  %s , 

[putitemon.objtoolow2.fem]
    %s  .
    %s  .    .

[putitemon.objtoolow2.masc]
    %s  .
    %s  .    .

[putno.objecthigh]
, %s  ,    .
 , %s  .

[putno.objectlow]
, %s  ,    .
 , %s  .

[object.hidden.from.view]
-    .
     .

[event.obj.hidden.masc]
 %s    .
  %s  .

[event.obj.hidden.fem]
 %s    .
  %s  .

[item.already.there]
  , %s
 , %s

[item.already.on]
     %s.
  %s.

[item.alreadyin]
     %s.
  %s.

[item.already.under]
     %s.
  %s.

[item.already.behind]
     %s.
  %s.

[item.already.at]
     %s.
  %s.

[object.selfrecurrence]
      .    .

[item.already.inhands]
   %s  .

[item.already.contained.inhands1]
%s 

[item.already.contained.inhands2.fem]
 %s,     .
 %s,      .

[item.already.contained.inhands2.masc]
 %s,     .
 %s,      .

[item.already.contained.inhands2.neut]
 %s,     .
 %s,      .

[item.already.contained.inhands3]
(  %s -,   ).

[player.handsfull]
   .   %s.
     %s,       -?

[putitemon.notmobile.fem]
 %s   .   .
  %s  ,  ,       .

[putitemon.notmobile.masc]
 %s  .   .
    %s.   .

[putitemon.notmobile.neut]
 %s   .      .
 %s   .   .

[item.around.generic]
 
 

[takeitem.light]
  %s,
  %s, 

[takeitem.big]
    %s,
     %s, 

[takeitem.kotoro.fem]
 

[takeitem.kotoro.masc]
 

[takeitem.kotoro.neut]
 

[takeitem.ground1]
 

[takeitem.floor1]
 

[surface.many]
  %s : 
 ,    %s : 

[nonedible.generic]
 .
  .

[roomdesc.generic]
  ,    .
,    ,    .

[takefixed.generic]
  %s  ,   .
     %s,    .

[put.noprep.remind]
 %s   <b><i></b></i> -  <b><i></b></i> -.
 ,     %s.

[open.generic]
  %s   .
˸     %s    .

[open.no.generic]
  .

[open.generic.folse.fem]
 %s  ,   .
  %s   ,   .

[open.generic.folse.masc]
 %s  ,   .
  %s   ,   .

[open.generic.folse.neut]
 %s  ,   .
  %s   ,   .

[gender.problem]
  %s   .

[close.generic.folse.fem]
 %s  ,   .
  %s   ,   .

[close.generic.folse.masc]
 %s  ,   .
  %s   ,   .

[close.generic.folse.neut]
 %s  ,   .
  %s   ,   .

[close.generic.tru]
     %s. 

[look.closed.item.generic.fem]
   % .

[look.opened.empty.generic.fem]
 %s .
    %s,    .
 %s  .
    %s,   , ,  . .
   %s,  ,   .

[look.opened.empty.generic.masc]
 %s .
   %s,  ,   .
 %s  .  .
    %s,    .

[look.opened.empty.generic.neut]
 %s .
   %s,  ,   .
 %s  .  .
    %s,    .

[look.container.nonempty.obscured]
 %s, , - ,     ,  .
 %s  - ,    ,  .

[look.checkon.nonempty.obscured]
Ha %s, , - ,   ,  .
Ha %s - ,   ,  .

[look.checkon.empty.obscured]
,  %s  .
,  %s  ,      .

[look.container.empty.obscured]
    ,  ,  %s  .
,  %s   ,      .

[look.container.empty.fem]
,  %s .
 ,  %s .

[look.checkon.empty.util]
 %s  .

[look.checkon.empty.surface]
 ,   %s .

[look.container.empty.masc]
,  %s .
 ,  %s .

[look.container.empty.neut]
,   %s .
 ,   %s .

[openspecial.failed1]
 %s
  %s

[openspecial.failed2]
%s   .
%s   .

[openlocked.fail.generic.fem]
   %s ,  ,  ,   .
    %s ,   , ,     .
    %s,         . <br>  .  ,  ,   .

[openlocked.fail.generic.masc]
   %s ,  ,  ,   .
    %s ,   , ,    .
    %s,         . <br>,   .  ,  ,   .

[openlocked.fail.generic.neut]
   %s ,  ,  ,   .
    %s ,   , ,    .
    %s,         . <br>,     .  ,    .

[entity.noask.generic]
    ,       .

[entity.ask.generic]
       , -   ,    .
  -  .

[testroom.floor.one]
 ,     %s.

[testroom.floor.many]
  : 

[inventory.empty]
     .
   ,     .

[drop.generic]
  %s  .
   %s  .

[drop.defuult]
   ,   %s  .
   ,   %s  .

[put.objekt.vague]
 -? , .

[puton.generic.full1]
 %s   , 

[puton.generic.full2]
%s   .

[putin.generic.full1]
 %s   , 
 %s    , 

[putin.generic.full2]
%s    .
%s   .

[putin.generic.from]
  %s 
  %s 

[putin.generic.into]
 %s.
  %s.

[puton.nosurface1]
 %s   ,
 %s    ,

[puton.nosurface2]
   %s.
   %s.

[hands.full1]
    ,       %s, 
     %s, 

[hands.full2]
   %s,    - .
   %s  .  . 

[hands.takeitem1]
  %s
  %s

[hands.takefrom.on.hardcase]
 %s

[hands.takefrom.on.softcase]
 %s

[takefrom.floor.fem]
  %s,   
    %s

[takefrom.floor.masc]
  %s,   
    %s

[takefrom.floor.neut]
  %s,   
    %s

[takefrom.ground.fem]
  %s,   
    %s

[takefrom.ground.masc]
  %s,   
    %s

[takefrom.ground.neut]
  %s,   
    %s

[takefrom.ison]
  %s

[takefrom.ison.hard]
   %s

[takefrom.ison.soft]
   %s

[takefrom.ishung]
  %s

[takefrom.ishung.hard]
   %s

[takefrom.ishung.soft]
   %s

[takefrom.isin]
  %s
  %s
  %s

[takefrom.isin.ctn]
   %s
   %s
   %s

[takeitem.generic]
  %s

[takefrom.isbehind]
  %s
  %s


[takefrom.isunder]
  %s
  %s

[takefrom.isunder.ctn]
  - %s
  - %s


[hands.take.fembak]
,    ,    ,     .

[hands.take.mascbak]
,    ,    ,     .

[hands.take.neutbak]
,    ,    ,     .

[item.putdown.needed]
  ,   %s,   -  .
     %s,    .

[hands.takeitem2]

[karman.takeitem1]
  %s 

[contained.takeitem1]
  %s 

[karman.takeitem2]
    .

[takeitem.contained1]
  %s 

[takeitem.contained2]
 %s 

[item.hidden.fromvu]
   .
    .
-     .

[put.object.multi]
      .  - .

[puton.generic.from]
  %s 
  %s 

[puton.generic.into]
 %s.
  %s.

[puton.generic.onto]
 %s.
  %s.

[puton.generic.nogo.from]
 %s 

[putin.generic.nogo.from]
 %s 

[puton.generic.nogo.onto]
 %s .
 %s   .

[put.generic.nogo.into]
 %s .
 %s   .

[putin.generic.nogo.into]
 %s .
 %s   .

[put.whylocked.generic.fem]
 , %s .
  ,  %s .

[put.whylocked.generic.masc]
 , %s .
  ,  %s .

[put.whylocked.generic.neut]
 , %s .
 , %s .
  ,  %s .

[takeall.negative]
   "".    .
    "",       : <br>)  <br>) . <br>
,   ,    .

[takefixed.generic]
    ,    .

[put.fixed.generic]
   ,    .

[breakfixed.generic]
 %s  .       .
, ,   %s,    .
 %s  .

[brekk.order.reminder]
<br><br><i> ,       <b></b>   ,   <b></b>    . : <b>  .</b></i>

[brekk.object.withsomethin1]
,   %s 
  %s 
        ,   %s 

[brekk.object.withsomethin1]
%s  ,  -    .
%s  ,    - .
%s,  -  ; ,   .

[somethin.under]
<br> %s, , - .
<br> %s - .
<br> %s - .

[putunder.nogo]
 %s   .

[putunder.nogo2]
  %s. 
 %s  .

[onprop.item.fem]
,  
,   

[onprop.item.masc]
,  
,   

[onprop.locatt.one]



[onprop.locatt.mult]



[floor.contain.one]
   %s.
   %s.

[floor.contain.many]
   : 
 ,     : 

[touch.generic]
      .
   -   .

[study.generic]
<b> ,      .</b>
<b>     .</b>

[climb.one]
      %s.

[climb.two]
      %s.

[climb.success1]
   %s.
   %s.

[climb.nogo]
 %s  .

[throw.object.inne.noresult1]
 ,     %s 
    %s 

[dropp.object.inne.noresult1]
 ,     %s 
    %s 

[throw.object.inne.noresult2]
 %s,      .
 %s,   , ,     .

[throw.object.at.noresult1]
 ,     %s 
    %s 

[dropp.object.at.noresult1]
 ,     %s 
    %s 

[throw.object.at.noresult2]
 %s,      .
 %s,   , ,     .

[throw.up.generic]
   %s ,      .
   %s ,     .

[dropp.up.generic]
   %s ,      .
   %s ,     .

[throw.object.noprep1]
   ,    %s 
    , ,       %s 

[dropp.object.noprep1]
   ,    %s 
    , ,       %s 

[throw.object.noprep1]
 %s,       .
 %s,   , ,     .

[throw.yourself.at]
    %s.   ?
    %s.  ,     ?

[throw.yourself.into]
    %s.   ?
    %s.  ,     

[throw.yourself.some]
 -,     %s.      ?
,    %s     .  .     ?

[drop.negative]
     %s? ?  ?
 %s  .

[dropdown.fromkarman]
    %s    .

[dropdown.fromhands]
  %s  .

[dropdown.fromhands.fem]
  %s  .

[dropdown.fromhands.masc]
  %s  .

[dropdown.fromhands.neut]
  %s  .

[putdown.fromhands.fem]
,    %s,   
  %s,    ,
  %s

[putdown.fromhands.masc]
,    %s,   
  %s,    ,
  %s

[putdown.fromhands.neut]
,    %s,   
  %s,    ,
  %s

[noputdown.dropped]
%s    .
%s      .
[inventory.one]
   ,    %s.

[inventory.many]
     
   ,   

[prop.caption.generic]
 

[status.blank]
.................

[voice.blank]

[status.stort]
...

[status.start]
 .

[look.default]
   .<br>
   ,   .<br>

[status.one]
......... 

[game.start]
    .<stop><br><br>-... <stop>...<stop><clear> -  .<stop><br><br> .

[box.open.generic]
  .

[boks.open.folse]
  .
    .

[boks.close.folse]
  .
    .

[box.close.generic]
  .

[room.look.invalid]
  %s,   .

[button.further]
<p align = "right"><a href = "look">&raquo;&raquo;</a></p>

[prop.gendesc]
  %s .

[udilo.look.generic]
   .

[udilo.caption]

 

[udilo.capcaption]


[udilo.accaption]


[udilo.gecaption]


[udilo.precaption]


[udilo.utilcaption]

 

[pol.caption]

[pol.accaption]

[pol.gecaption]



]]

slib : add( "ru", ru )
slib : set "ru"
--======================================================================================
function move_node (obj, target)
	if obj.parent then
		remove_node (obj)
	end
	obj.parent = target
	if not target.items then
		target.items = {}
	end
	table.insert (target.items, obj)
end


function remove_node (obj)
	local items = obj.parent.items
	for i, item in ipairs(items) do
		if items [i] == obj then
			table.remove (items, i)
			break
		end
	end
	
	if obj.parents then
		local ps
		ps, obj.parents = obj.parents, nil
		while table.getn (ps) ~= 0 do
			obj.parent = ps [table.getn(ps)]
			table.remove (ps)
			remove_node (obj)
		end
	end
end


function show_tree (node, level)
	if not node then
		node, level = world, 0
	end
	
	print (string.rep ("\t", level)..node.uid)
	
	if not node.items then
		return
	else	
		for i, v in ipairs (node.items) do
			show_tree (v, level + 1)
		end
	end
end


function show_parents (node)
	print (node.uid)
	if node.parent then
		show_parents (node.parent)
	end
end
--======================================================================================
ifobject = {}

function ifobject:add (...)
	if not self.items then
		self.items = {}
	end

	if type (arg [1]) == "table" then
		for i, v in ipairs (arg) do
			if not v.parent  then
				move_node (v, self)
			else
				table.insert (self.items, v)
				if not v.parents then
					v.parents = {}
				end
				table.insert (v.parents, self)
			end
		end
	else
		if not self.hooks then
			self.hooks = {}
		end
		table.insert (self.hooks, arg [1])
	end
end


function ifobject:moveto (target)
	move_node (self, target)
end


function ifobject:remove (object)
	if not object then
		if self.parent then
			remove_node (self)
		end
	else
		for i, v in ipairs( self.items ) do
			if v == object then
				table.remove (self.items, i)
				return
			end
		end
	end
end


function ifobject:show ()
	show_tree (self, 0)
end

local ifobject_meta = {
	__index = function( self, key )
		local result
		if self.data.parent then
			local parent = _G[self.data.parent]
			if parent and parent ~= self and key ~= "items" then
				result = parent[key]
			end
		end
		if type(result) == "nil" then
			result = self.data[key]
		end		
		return result
	end,
	__newindex = function( self, key, value )
		if type(self.data[key]) ~= "nil" then
			self.data[key] = value
		else
			rawset(self, key, value)
		end
	end
}

function create_ifobject (uid, name)
	local obj = clone (ifobject, {["uid"] = uid, ["name"] = {}, data = {}, caption = ""})
	setmetatable( obj, ifobject_meta )
	getfenv(0)[uid] = obj
	obj.name = name	
	return obj
end


function ifobject:create (uid, name)
	self:add (create_ifobject (uid, name))
end


function ifobject:find (name, list)	
	if not list then list = {} end

	if string.len (self.name) ~= 0 then
		local addthis = true
		for i, noun in ipairs (name) do
			if not string.find (self.name, noun) and noun ~= "all" then
				addthis = false
				break
			end
		end
		
		if table.getn (name) == 1 and name [1] == "all" then
			addthis = false
		end
		
		if addthis then
			table.insert (list, self)
		end
	end
	
	if self.items then
		for i, item in ipairs (self.items) do
			item:find (name, list)
		end
	end
	
	return list
end

function ifobject:isme( name )
	local rest = self.name
	for i, n in ipairs(name) do rest = string.gsub( rest, n, "" ) end
	return not string.find( rest, "%S" )
end


function ifobject:contains (object)
	if self == object then
		return true
	end
	
	if self.items then
		for i, item in ipairs (self.items) do
			if item:contains (object) then
				return true
			end
		end
	end
	
	return false
end


function ifobject:clone (object, uid)
	local temp1, temp2, temp3
	object.items, object.parent, object.parents, temp1, temp2, temp3 = {}, nil, nil, object.items, object.parent, object.parents
	local result = clone (object)
	object.items, object.parent, object.parents = temp1, temp2, temp3
	result.parent = nil
	result.uid = uid
	getfenv(0) [uid] = result
	result:moveto (self)
end

function ifobject:check (parent, cookie)
	cookie = cookie or { }
	if self ~= _G[self.uid] then
		print ("  "..self.uid.."  "..parent.uid)
		parent:remove (self)
		return
	end

	if cookie[self] then
		print (self.uid.."    "..parent.uid..".  ...")
		parent:remove (self)
		return
	end
	cookie[self] = true
	if self.items then
		for i, v in ipairs( self.items ) do
			v:check (self, cookie)
		end
	end
	cookie[self] = nil
end


function ifobject:belongto (object)
	if self.parent then
		local next = self.parent
		while next do
			if next == object then
				return true
			end
			next = next.parent
		end
	else
		return false
	end
	return false
end


function ifobject:count ()
	if not self.items then
		return 0
	end

	return table.getn (self.items)
end


--======================================================================================
function start ()
	while true do
		io.output():write ('> ')
		parse (io.input():read())
		print ("")
	end
end


function save_node (node, file)
	if node.data then
		file:write (node.uid..".data = ")
		dump_table (node.data, file)
		file:write ("\n")
	end
	
	file:write (node.uid..".name = '"..node.name.."'\n")
	if (node.parent) then
		file:write (node.uid..":moveto ("..node.parent.uid..")\n")
	end
	
	if node.items then
		for i, v in ipairs( node.items ) do
			save_node (node.items [i], file)
		end
	end
end


function save (filename)
	local file = io.open (filename, "w")
	save_node (world, file)
	file:close()
end


function free_node (node)
	while node.items and table.getn (node.items) ~= 0 do
		free_node (node.items [1])
	end
	
	node:remove ()
end


function load (filename)
	free_node (world)

	dofile (filename)
end

--======================================================================================
PARSE_ERROR = {[[
      .]], [[
    .]], [[
,     .]], [[
   "".]], [[
    .]], [[
    .]], [[
     .  .]], [[
,      .]], [[
 - .]]}

sixdays_print_error = print

function parsing_error (error)
	local pe = PARSE_ERROR [error + 1]
	local temp, n = string.gsub (pe, "[^\n\r]+", " ")
	n = math.random (n)
	temp = 1
	string.gsub (pe, "[^\n\r]+", function (s)
		if temp == n then
			sixdays_print_error (s)
		end
		temp = temp + 1
	end)
end
--======================================================================================

create_ifobject ("world", "")
world:create ("player", "")
world.items = {}
function world:setcolor (event)
x:fgcolor "#571B7e"
x:bgcolor "#E3E4FA"
end
function world:s_up (event)
world:chfont (event)

player:moveto (testroom)

x:p "$(newstatus (slib.status.stort()))"

x:pln (slib.game.start())
x:p "$(newstatus (slib.status.start()))"

-- player.parent:look (event)
end
function world:chfont (event)
if stash.dark then

x:bgcolor "#000066"
x:fgcolor "#FFFF99"

-- x:fgcolor "#CCFF00"
	
	else 
	
-- x:bgcolor "#FFFFCC"
x:bgcolor "#FFFF99"
x:fgcolor "#663333"
	
	
end
end
function world:skey (event)

end
function world:constructor ()
math.randomseed( os.time() )

x:bgcolor "#FFFFCC"
x:fgcolor "#663333"

--   
x:body [[
<table width=100%>
<tr bgcolor=$(fgcolor)><td><i><font color=$(bgcolor)>$(player.status)</font></bgcolor></i></align>
<tr><td>$(output)
<tr><td>$(input)
<tr><td>$(g_error)
<tr><td>$(player.noises)

</table>	
]]



--   ----
x:on_input( function( text )
	g_error = ""; x:clear(); player.noises = ""; parse(text)
	if #g_error > 0 then x:restore() end
end )

--   
sixdays_print_error = function( text ) g_error = text end
g_error = ""

x:anykey "<table width=100% cellspacing=0 cellpadding=0><tr><td align=right><table><tr><td bgcolor=$(fgcolor)><font color=$(bgcolor)>&raquo;&raquo;&raquo; -- </font></table></table>"

--   
x.tags.inv = "<b>"
x.tags.ob = "<font color=#993300>"
x.tags.sp = "<i>"
x.tags.bigger = "<font size=$(fontsize+1)>"
x.tags.smaller = "<font size=$(fontsize-1)>"
-- x.tags.nois = "<font color=$(fgcolor-1)>"


--  
newstatus = function(status) player.status = status end
newnoises = function(noises) player.noises = noises end

--      


world:s_up (event)

end

world.data = {
}world:create ('player', 'me')
function player:exit (event)

end
function player:ask (event)

end
function player:what (event)

end
function player:stand (event)

end
function player:constructor ()
world.dropcount = function (obj, cookie)
    local dropctr = 0
-- x:pln( obj.uid .. " " .. (obj.dropped and "dropped" or "not dropped") )
    if obj.dropped then  dropctr = 1 end
    if cookie then return dropctr end
    for i = 1, obj:count() do
        dropctr = dropctr +world.dropcount (obj.items[i], true)
    end
    return dropctr
end 

world.propcount = function (obj)
local propctr = 0
if obj.prop and not obj.contained then propctr = 1 end
for i = 1, obj:count() do
propctr = propctr + world.propcount (obj.items[i])
end
return propctr
end

world.entitycount = function (obj)
local entityctr = 0
if obj.entity then propctr = 1 end
for i = 1, obj:count() do
entityctr = entityctr + world.entitycount (obj.items[i])
end
return entityctr
end


world.mobcount = function (obj)
local mobctr = 0
if obj.mobile and not obj.big and not obj:belongto (player) then mobctr = 1 end
for i = 1, player.parent:count() do
mobctr = mobctr + world.mobcount (player.parent.items[i])
end
return propctr
end


world.oncount = function (obj)
-- x:pln "<b>world oncount initiated!</b>"
local onctr = 0
if obj.ison and not obj.hidden then onctr = 1 end
for i = 1, obj:count() do
onctr = onctr + world.oncount (obj.items[i])
end
return onctr
end

world.undercount = function (obj)
local underctr = 0
if obj.isunder and not obj.hidden then underctr = 1 end
for i = 1, obj:count() do
underctr = underctr + world.undercount (obj.items[i])
end
return underctr
end

world.behindcount = function (obj)
local behindctr = 0
if obj.isbehind and not obj.isin then behindctr = 1 end
for i = 1, obj:count() do
behindctr = behindctr + world.behindcount (obj.items[i])
end
return behindctr
end

world.containcount = function (obj)
-- x:pln "<b>ContainCount initiated!</b>"
local containct = 0
if obj.isin and not obj.hidden  then containct = 1 end
for i = 1, obj:count() do
containct = containct + world.containcount (obj.items[i])
end
return containct
end

world.propdesc_rec = function (obj) 
if obj.hidden then return end 
if obj.prop and not obj.contained then obj:do_desc (event) end 
for i = 1, obj:count() do 
local item = obj.items[ i ] 
world.propdesc_rec (item) 
end
end


world.mobdesc_rec = function (obj) 
if obj.hidden then return end 
if obj.mobile and not obj.contained then
x:pln "<i>    mobdesc_rec.</i>"
world.mobdesc (obj)  end 
for i = 1, obj:count() do 
local item = obj.items[ i ] 
world.mobdesc_rec (item) 
end
end

world.mobdesc = function (obj)
x:pln "<i>   .</i>"
local uid = obj.uid
local tzpka = math.random( 2 )
if obj.parent.prop and not obj.contained then
x:p "<br>"
local puid = obj.parent.uid

	if obj.onside then

		if tzpka == 1 then
		x:p (slib.itemon.generic1.desc1 ( slib[puid].precaption () ))
		x:p " "
		x:p (slib.itemon.generic1.desc2 ( slib[uid].caption () ))

		else 
		x:p (slib.itemon.generic2.desc1 ( slib[puid].gecaption () ))
		x:p " "
		x:p (slib.itemon.generic2.desc2 ( slib[uid].caption () ))

		end

	elseif obj.inside then 
	
		if tzpka == 1 then
		x:p (slib.itemin.generic1.desc1 ( slib[puid].precaption () ))
		x:p " "
		x:p (slib.itemin.generic1.desc2 ( slib[uid].caption () ))

		else 
		x:p (slib.itemin.generic2.desc1 ( slib[puid].gecaption () ))
		x:p " "
		x:p (slib.itemin.generic2.desc2 ( slib[uid].caption () ))

		end

	elseif obj.isbehind then 
	
		if tzpka == 1 then
		x:p (slib.itembehind.generic1.desc1 ( slib[puid].utilcaption () ))
		x:p " "
		x:p (slib.itembehind.generic1.desc2 ( slib[uid].caption () ))

		else 
		x:p (slib.itembehind.generic2.desc1 ( slib[puid].gecaption () ))
		x:p " "
		x:p (slib.itembehind.generic2.desc2 ( slib[uid].caption () ))

		end


	
	else 

	x:p (slib.itemat.generic ( slib[uid].caption () ))
	
	end	
else
--      " "  " " ,     .
--     world.dropdesc
x:pln (slib.locdesc.generic (slib[uid].caption () ))
end

end

world.open_checkifclosed = function (obj)
local uid = obj.uid
		if obj.closed then
		x:p " "
				
				if obj.fem then
				x:pln (slib.container.closed.fem (slib[uid].caption () ))
				elseif obj.masc then
				x:pln (slib.container.closed.masc (slib[uid].caption () ))
				elseif obj.neut then
				x:pln (slib.container.closed.neut (slib[uid].caption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end
		else
		x:p " "
				if obj.fem then
				x:pln (slib.container.open.fem (slib[uid].caption () ))
				elseif obj.masc then
				x:pln (slib.container.open.masc (slib[uid].caption () ))
				elseif obj.neut then
				x:pln (slib.container.open.neut (slib[uid].caption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end
--		x:p "ololo! Trying to look inside"
	 	obj:chek_inside (event)
		end 

end


world.open_container = function (obj)
local uid = obj.uid
if obj.closed then
	
--   ,     - 
			if obj.locked then
				if obj.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif obj.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif obj.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
--   ,    
			x:pln (slib.open.generic (slib[uid].accaption ()))
			obj.closed = false
			obj.locked = false
				if obj:count () ~= 0 then
					for i = 1, obj:count () do
					obj.items [ i ].data.hidden = false
					obj.items [ i ].data.obscured = false
					end						
				end
			end

--			x:p "ololo! Trying to look inside "
--			x:p (slib[uid].gecaption ())
		 	world.reveal_container (obj)

	
else
--      
			if obj.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].accaption ()))
			elseif obj.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif obj.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
		end
end

world.container_empty = function (obj)
				local uid = obj.uid
				if obj.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif obj.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif obj.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end
end



world.container_close = function (obj)
local uid = obj.uid
	if obj.closed then
		if obj.fem then
		x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
		elseif obj.masc then
		x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
		elseif obj.neut then
		x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
		else 	
		x:pln (slib.gender.problem (slib[uid] () ))
		end

	else 
		x:pln (slib.close.generic.tru (slib[uid].accaption ()))
		obj.data.closed = true
					for i = 1, obj:count () do
					obj.items [ i ].data.hidden = true
					obj.items [ i ].data.obscured = true
					end	
end
end				
end

player:add (function (event)
if event.after then

	if event.target == all then
	x:pln (slib.takeall.negative ())	
	end
	
return false
end
return true
end)
function player:help (event)

end
function player:inventory (event)
-- x:pln "$(player:chekinv())<stop>"
local K = karman:count ()
	if K == 0 then
	x:pln (slib.inventory.empty() )


	elseif K == 1 then
		local uid = karman.items[ K ].uid
		x:pln (slib.inventory.one( slib[uid].accaption() ) )

	else


x:p ( slib.inventory.many() )
x:p " "
	local N = karman:count()
	local V = N - 1
-- uid  
	local vuid = karman.items[ V ].uid
	local lastuid = karman.items[ N ].uid

		for i = 1, N - 2 do
		local muid = karman.items[ i ].uid
		x:p (slib[muid].caption())
		x:p ", "
		end
	x:p (slib[vuid].caption() )
	x:p "  "
	x:p (slib[lastuid].caption() )
	x:p "."

end



end
function player:test (event)
x:pln( molotok.dropped and "  !" or "   " )
end
function player:look (event)
self.parent:look (event)

--   ,   
-- x:p " "
for i = 1, self.parent:count() do
local items = self.parent.items [ i ]
if items.prop and not items.dropped and not items.important and not items.entity then
items:do_desc (event)
end
end

--   
for i = 1, self.parent:count() do
local items = self.parent.items [ i ]
if items.important and not items.concealed and not items.hidden then
items:do_desc (event)
end
end

self:reveal_dropped (event)

-- x:p "<br>"
--   .   , .
world.reveal_entity (self.parent)

-- ,      
if hands:count () ~= 0 then	
x:p "<br>"
for i = 1, hands:count () do
local huid = hands.items[ 1 ].uid	
x:pln (slib.roomlook.hands (slib[huid].accaption() ) )
end
end


end
function player:cunt (event)
x:pln( count_all(world) )
end
function player:reveal_dropped (event)
-- ,      
-- x:p " dropped"
local par = self.parent
local P = world.dropcount (par)
local dropped_only = { }
for i = 1, par:count() do
if par.items[ i ].dropped then table.insert (dropped_only, par.items[ i ]) end
end

if P == 0 then 
x:p " "

elseif P == 1 then
for i = 1, P do
local itemuid = dropped_only[ i ].uid
x:p "<br>"
x:pln (slib.floor.contain.one ( slib[itemuid].caption() ))
end

else 

x:p "<br>"

	x:p ( slib.floor.contain.many() )
	x:p " "


	local Z = P - 1
-- uid  
	local vuid = dropped_only[ Z ].uid
	local lastuid = dropped_only[ P ].uid

		for i = 1, P - 2 do
		local muid = dropped_only[ i ].uid
		x:p (slib[muid].caption())
		x:p ", "
		end
	x:p (slib[vuid].caption() )
	x:p "  "
	x:p (slib[lastuid].caption() )
	x:p "."
	
end

end
player.data = {
}player:create ('karman', 'karman')
karman.data = {
}player:create ('factas', '')
factas.data = {
}factas:create ('fact1', '')
fact1.data = {
fact = true,
}player:create ('fantoms', '')
fantoms.data = {
}fantoms:create ('upp', 'naverx')
upp.data = {
}fantoms:create ('mylegs', '')
mylegs.data = {
}fantoms:create ('floor', 'floor')
function floor:look (event)

end
function floor:lie (event)

end
floor.data = {
}fantoms:create ('hands', 'hand')
hands.data = {
}fantoms:create ('meself', 'myself')
function meself:brek (event)
x:pln (slib.player.brek.nogo () )
end
function meself:look (event)
x:pln (slib.player.desc.generic () )

if player.high then

local cuid = player.climbed_at
	local tzpka = math.random (2)
	if tzpka == 1 then
	x:pln (slib.climbed.reveal1 (slib[cuid].accaption () ) )
	else
	x:pln (slib.climbed.reveal2 (slib[cuid].precaption () ) )
	
	end

end

-- ,      
if hands:count () ~= 0 then	
for i = 1, hands:count () do
local huid = hands.items[ 1 ].uid	
x:pln "<br>"
x:pln (slib.roomlook.hands (slib[huid].accaption() ) )
end
end
end
meself.data = {
}fantoms:create ('_all', 'all')
function _all:pute (event)


end
function _all:take (event)
local par = player.parent
local P = world.allcount (par)
local small_items = { }
for i = 1, par:count() do
if not obj.prop and not obj.hidden and not obj.entity and not obj.big and not obj.high and not player.high or not obj.prop and not obj.hidden and not obj.entity and not obj.big and obj.high and player.high  then table.insert (small_items, par.items[ i ]) end
end
end
function _all:look (event)

end
function _all:dropp (event)

end
function _all:constructor ()
world.allcount = function (obj)
local allctr = 0
if not obj.prop and not obj.hidden and not obj.entity and not obj.big and not obj.high and not player.high or not obj.prop and not obj.hidden and not obj.entity and not obj.big and obj.high and player.high then allctr = 1 end
for i = 1, obj:count() do
allctr = allctr + world.allcount (obj.items[i])
end
return allctr
end
end

_all.data = {
}world:create ('stash', '')
function stash:constructor ()

end

stash.data = {
}world:create ('testroom', 'room')
function testroom:do_dropped (event)

end
function testroom:do_below (event)

end
function testroom:do_behind (event)

end
testroom:add (function (event)
if event.after then
-- ,    ,     
-- ,     
--  


return false
end
return true
end)
function testroom:do_desc (event)

end
function testroom:look (event)
--   ,      
if self.looked then

else
x:pln (slib.roomdesc.generic ())
end

--      .
-- world.propdesc_rec (self)
-- x:p "<br>"
-- world.mobdesc_rec (self)

--local drop = world.dropcount (self)
-- if drop ~= 0 then
-- world.do_dropped (self)
-- end

-- if hands:count () ~= 0 then	
-- 	for i = 1, hands:count () do
-- 	local huid = hands.items[ 1 ].uid	
-- 	x:p "<br>"
-- 	x:pln (slib.roomlook.hands (slib[huid].accaption() ) )
-- 	end
-- end

end
function testroom:constructor ()
testroom.data.drop_ctr = 0
testroom.data.floor = true

--    "look" : 
--   do_desc  ,    
--    check_prop  ,           prop  do_prop
--   check_mobile,   do_mobile      mobile
--   check_entity,   do_entity     entity


end

testroom.data = {
drop_ctr = 0,
floor = true,
}testroom:create ('stol', 'stol')
function stol:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function stol:climb (event)
local uid = self.uid
if self.climbable then

	if player.climbed_at == self.uid then
		local tzpka = math.random (2)
		if tzpka == 1 then
		x:pln (slib.climb.one (slib[uid].accaption () ) )
		--       .
		else
		x:pln (slib.climb.two (slib[uid].precaption () ) )

		end
	else
		
		player.data.climbed_at = self.uid
		player.data.high = true
		--  \ 
		x:pln (slib.climb.success1 (slib[uid].accaption () ) )

		
	end
else 

x:pln (slib.climb.nogo (slib[uid].accaption () ) )

end
end
function stol:study (event)
if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
	else

x:pln (slib.study.generic ())
end
end
function stol:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function stol:pute (event)
local ouid = event.object.uid
local tuid = event.target.uid

--      

if self.fixed then

x:pln (slib.put.fixed.generic ())

else


--  ,    

	if not event.object then
		x:p "kolbasa"
		self:moveto (player.parent)
		self.data.dropped = true
		x:pln (slib.drop.generic (slib[tuid].accaption()))

		
--		if not event.objects then
--		x:pln (slib.put.object.vague ())
--		else
--		x:pln (slib.put.object.multi ())
--
--		end
	

	else

--   

		if event.prep[2] == "on" then

--   "",    ,   

	
			if event.object.surface then

				event.object:chwt (event)
				if event.object.full then

				x:pln (slib.puton.generic.full1 ( slib[tuid].gecaption () ))
				x:pln (slib.puton.generic.full2 ( slib[ouid].caption () ))

				else
				x:pln (slib.puton.generic.from ( slib[tuid].accaption () ))
				x:p (slib.puton.generic.onto ( slib[ouid].gecaption () ))
	
				self:moveto (event.object)
				self.data.onside = true
				end
			else 

			x:pln (slib.puton.generic.nogo.from ( slib[tuid].accaption () ))
			x:p (slib.puton.generic.nogo.onto ( slib[ouid].accaption () ))

				
			end
	


--   "",      ""
		elseif event.prep[2] == "in" then


			if event.object.container then
				if event.object.locked then
					if event.object.fem then 
					x:p (slib.put.whylocked.generic.fem ( slib[ouid].caption () ))
					elseif event.object.masc then 
					x:p (slib.put.whylocked.generic.masc ( slib[ouid].caption () ))			
					elseif event.object.neut then 
					x:p (slib.put.whylocked.generic.neut ( slib[ouid].caption () ))
					end
				else
			
					event.object:chwt (event)
					if event.object.full then

					x:pln (slib.putin.generic.full1 ( slib[tuid].gecaption () ))
					x:pln (slib.putin.generic.full2 ( slib[ouid].caption () ))

					else
					x:pln (slib.putin.generic.from ( slib[tuid].accaption () ))
					x:p (slib.putin.generic.into ( slib[ouid].gecaption () ))
	
					self:moveto (event.object)
					self.data.inside = true
					end
				end
			else 

			x:pln (slib.putin.generic.nogo.from ( slib[tuid].accaption () ))
			x:p (slib.putin.generic.nogo.into ( slib[ouid].accaption () ))

				
			end



--   ,     

		else 
		x:pln (slib.put.noprep.remind (slib[ouid].accaption () ) )
		end
	end		
end
end
function stol:sdvin (event)

end
function stol:eat (event)
x:pln (slib.nonedible.generic ())
end
function stol:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	world:lookbehind (self) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
-- 	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
	end
else
x:pln (slib.item.hidden.fromvu () )
end

end
function stol:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function stol:openspecial (event)
x:pln " (   OPEN)      ."
end
function stol:throwe (event)
if not event.target then
local ouid = event.object.uid 
	if event.prep[1] == "at" then
	x:pln (slib.throw.yourself.at (slib[ouid].accaption () ) )
	elseif event.prep[1] == "into" then
	x:pln (slib.throw.yourself.into (slib[ouid].accaption () ) )
	else
	x:pln (slib.throw.yourself.some (slib[ouid].accaption () ) )
	end
	
else 
if event.object then
	local ouid = event.object.uid
	local uid = self.uid
	
	if event.prep[2] == "in" then
	x:pln (slib.throw.object.inne.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
--      

	elseif event.prep[2] == "at" then
	x:pln (slib.throw.object.at.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

--      

	else 
--     
		if event.object == naverx then

-- ,      

		x:pln (slib.throw.up.generic (slib[uid].accaption () ) )
		

		else

		--       
								
--     , ,      "".

x:pln (slib.throw.object.noprep1 (slib[uid].utilcaption () ) )
x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


		end
	end
	
else 

self:dropdown (event)
-- x:pln (slib.breakfixed.generic ())
--    DROPDOWN

end
end
end
function stol:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function stol:do_pres (event)

end
function stol:burn (event)

end
function stol:stand (event)
self:climb (event)
end
function stol:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function stol:spusk (event)
local uid = self.uid
if player.climbed_at == self.uid then

	if self.hardcase then
	x:pln (slib.climb.down.hardcase (slib[uid].gecaption () ) )
	else
	x:pln (slib.climb.down.softcase (slib[uid].gecaption () ) )
	end
--    
player.climbed_at = false
player.high = false		
else	
x:pln (slib.climb.down.nogo (slib[uid].accaption () ) )

--     .

end
end
function stol:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION

--     LOCKED (   )  FULL     .
--     SURFACE    FULL,   .
--      CHWT   .

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP

stol.data.surface_ctr = 0
end

function stol:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function stol:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function stol:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function stol:chek_inside (event)
local uid = self.uid


--   ,      ""

if self.closed then
				

	
else

if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:p (slib.item.inside.one.desc1( slib[uid].precaption() ))
		x:p " "
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
end
function stol:take (event)
local uid = self.uid

if self.fixed then

x:pln (slib.takefixed.generic (slib[uid].accaption () ))	

else
	if self:belongto (karman) then
	x:pln (slib.notake.already (slib[uid].caption ()) )
	else
		
		if self.big then

--  Ш  ,    
			local huid = hands.items[ 1 ].uid	
			if hands:count () ~= 0 then			
			x:pln (slib.hands.full1 (slib[huid].utilcaption() ) )
			x:p (slib.hands.full2 (slib[uid].accaption() ) )
			else
			x:p (slib.hands.takeitem1 (slib[uid].accaption() ) )
			self:moveto (hands)
			end
		else
--  Ĩ  			
		x:p (slib.karman.takeitem1 (slib[uid].accaption() ) )
		self:moveto (karman)
		
		end
	end

end
end
function stol:do_desc (event)
local uid = self.uid
x:p (slib[uid].locdesc.generic ())
x:p "<br>"
if self.hason then
	
world.desc_on (self)
	
end


if player.climbed_at == uid then
x:p " "
	if self.masc then
	x:pln (slib.climb.descitem.masc (slib[uid].accaption () ) )
	elseif self.fem then
	x:pln (slib.climb.descitem.fem (slib[uid].accaption () ) )
	else
	x:pln (slib.climb.descitem.neut (slib[uid].accaption () ) )	
	end

end

end
function stol:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function stol:dropp (event)
if event.object then
	local ouid = event.object.uid
	local uid = self.uid
	
	if event.prep[2] == "in" then
	x:pln (slib.dropp.object.inne.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
--      

	elseif event.prep[2] == "at" then
	x:pln (slib.dropp.object.at.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

--      

	else 
--     
		if event.object == naverx then

-- ,      

		x:pln (slib.dropp.up.generic (slib[uid].accaption () ) )
		

		else

		--       
								
--     , ,      "".

x:pln (slib.dropp.object.noprep1 (slib[uid].utilcaption () ) )
x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


		end
	end
	
else 

self:dropdown (event)

--    DROPDOWN

end
end
stol.data = {
surface = true,
hason = true,
writable = true,
prop = true,
closed = true,
dropped = false,
burnable = true,
surface_ctr = 0,
hardcase = true,
masc = true,
fixed = true,
hasunder = true,
climbable = true,
}testroom:create ('skaf', 'skaf')
function skaf:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function skaf:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function skaf:study (event)
if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
	else

x:pln (slib.study.generic ())
end
end
function skaf:clous (event)

if event.object then
	if event.object.opener or self.opener and event.object  then

	self:lokk (event)

	else 
	end
else
	
	local uid = self.uid
	for i = 1, self:count() do
	local items = self.items [ i ]

	if self.closed then
		if self.fem then
		x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
		elseif self.masc then
		x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
		elseif self.neut then
		x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
		else 	
		x:pln (slib.gender.problem (slib[uid] () ))
		end

	else 
		local uid = self.uid
		x:pln (slib.close.generic.tru (slib[uid].accaption ()))

		self.data.closed = true
		items.data.hidden = true

			
end
end
end
end
function skaf:pute (event)
local ouid = event.object.uid
local tuid = event.target.uid

--      

if self.fixed then

x:pln (slib.put.fixed.generic ())

else


--  ,    

	if not event.object then
		if not event.objects then
		x:pln (slib.put.object.vague ())
		else
		x:pln (slib.put.object.multi ())

		end
			
		

	else

--   

		if event.prep[2] == "on" then

--   "",    ,   

	
			if event.object.surface then

				event.object:chwt (event)
				if event.object.full then

				x:pln (slib.puton.generic.full1 ( slib[tuid].gecaption () ))
				x:pln (slib.puton.generic.full2 ( slib[ouid].caption () ))

				else
				x:pln (slib.puton.generic.from ( slib[tuid].accaption () ))
				x:p (slib.puton.generic.onto ( slib[ouid].gecaption () ))
	
				self:moveto (event.object)
				self.data.onside = true
				end
			else 

			x:pln (slib.puton.generic.nogo.from ( slib[tuid].accaption () ))
			x:p (slib.puton.generic.nogo.onto ( slib[ouid].accaption () ))

				
			end
	


--   "",      ""
		elseif event.prep[2] == "in" then


			if event.object.container then
				if event.object.locked then
					if event.object.fem then 
					x:p (slib.put.whylocked.generic.fem ( slib[ouid].caption () ))
					elseif event.object.masc then 
					x:p (slib.put.whylocked.generic.masc ( slib[ouid].caption () ))			
					elseif event.object.neut then 
					x:p (slib.put.whylocked.generic.neut ( slib[ouid].caption () ))
					end
				else
			
					event.object:chwt (event)
					if event.object.full then

					x:pln (slib.putin.generic.full1 ( slib[tuid].gecaption () ))
					x:pln (slib.putin.generic.full2 ( slib[ouid].caption () ))

					else
					x:pln (slib.putin.generic.from ( slib[tuid].accaption () ))
					x:p (slib.putin.generic.into ( slib[ouid].gecaption () ))
	
					self:moveto (event.object)
					self.data.inside = true
					end
				end
			else 

			x:pln (slib.putin.generic.nogo.from ( slib[tuid].accaption () ))
			x:p (slib.putin.generic.nogo.into ( slib[ouid].accaption () ))

				
			end



--   ,     

		else 
		x:pln (slib.put.noprep.remind (slib[ouid].accaption () ) )
		end
	end		
end
end
function skaf:eat (event)
x:pln (slib.nonedible.generic ())
end
function skaf:look (event)
if event.prep[1] == "under" then

world.lookunder (self)

elseif event.prep[1] == "behind" then

world.lookbehind (self) 

elseif event.prep[1] == "into" or event.prep[1] == "in" then

	if self.closed then
			local uid = self.uid
			if self.fem then
			x:pln (slib.container.closed.fem (slib[uid].caption () ))
			elseif self.masc then
			x:pln (slib.container.closed.masc (slib[uid].caption () ))
			elseif self.neut then
			x:pln (slib.container.closed.neut (slib[uid].precaption () ))
			else 	
			x:pln (slib.gender.problem (slib[uid] () ))
			end
	
	self:look2glass (event)
	
	else
	self:chek_inside (event)
	end 
else 

	local uid = self.uid
	
self:do_desc (event)
		if self.closed then
		self:look2glass (event)
--         
		else
		
		self:chek_inside (event)

		end		

--		if self.surface then

--		self:chek_surfac (event)

--		end

end	

end
function skaf:sdvin (event)
if player.high then

x:pln (slib.skaf.sdvig.nogo () )

else

	if self.sdvig then
		if stash.radio_checked then
		x:pln (slib.skaf.sdvigback1 () )	
		radio.data.concealed = true	
		else
		
		x:pln (slib.skaf.sdvigback2 () )		
		radio.data.hidden = true	
		
		end
	
	else 

	if stash.radio_checked then

	x:pln (slib.skaf.sdvigleft1 () )		
	self.data.sdvig = true
	radio.hidden = false
	radio.concealed = false
	
	else

	x:pln (slib.skaf.sdvigleft.seeradio () )		
	stash.data.radio_checked = true
	radio.hidden = false
	radio.concealed = false
	end

	end
	
	
end
end
function skaf:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function skaf:openspecial (event)
local uid = self.uid
local ouid = event.object.uid
		if kluch:belongto (player) then
			x:pln (slib.open.generic (slib[uid].accaption ()))
			world.reveal_container (self)
			for i = 1, self:count() do
			self.closed = false
			self.locked = false
			self.items [ i ].data.hidden = false
			end

--		elseif not event.object:belongto (player) and not event.object.hidden then
--		x:p (slib.open.item.around1 (slib[ouid].accaption () ) )
--		x:p " "
--		x:p (slib.open.item.around2 (slib[uid].accaption () ) )
--		x:p " "
--		x:p (slib.open.item.around3 (slib[ouid].accaption () ) )

		else
		x:p (slib.open.item.unavailable1 (slib[ouid].gecaption () ) )
		x:p " "
		x:p (slib.open.item.unavailable2 (slib[uid].accaption () ) )
		end

end
function skaf:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function skaf:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function skaf:chek_inside (event)
local uid = self.uid


--   ,      ""

if self.closed then
				

	
else

if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:p (slib.item.inside.one.desc1( slib[uid].precaption() ))
		x:p " "
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
end
function skaf:take (event)
local uid = self.uid

if self.fixed then

x:pln (slib.takefixed.generic (slib[uid].accaption () ))	

else
	if self:belongto (karman) then
	x:pln (slib.notake.already (slib[uid].caption ()) )
	else
		
		if self.big then

--  Ш  ,    
			local huid = hands.items[ 1 ].uid	
			if hands:count () ~= 0 then			
			x:pln (slib.hands.full1 (slib[huid].utilcaption() ) )
			x:p (slib.hands.full2 (slib[uid].accaption() ) )
			else
			x:p (slib.hands.takeitem1 (slib[uid].accaption() ) )
			self:moveto (hands)
			end
		else
--  Ĩ  			
		x:p (slib.karman.takeitem1 (slib[uid].accaption() ) )
		self:moveto (karman)
		
		end
	end

end
end
function skaf:burn (event)

end
function skaf:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function skaf:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION

--     LOCKED (   )  FULL     .
--     SURFACE    FULL,   .
--      CHWT   .

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP


end

function skaf:throwe (event)
if not event.target then
local ouid = event.object.uid 
	if event.prep[1] == "at" then
	x:pln (slib.throw.yourself.at (slib[ouid].accaption () ) )
	elseif event.prep[1] == "into" then
	x:pln (slib.throw.yourself.into (slib[ouid].accaption () ) )
	else
	x:pln (slib.throw.yourself.some (slib[ouid].accaption () ) )
	end
	
else 
if event.object then
	local ouid = event.object.uid
	local uid = self.uid
	
	if event.prep[2] == "in" then
	x:pln (slib.throw.object.inne.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
--      

	elseif event.prep[2] == "at" then
	x:pln (slib.throw.object.at.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

--      

	else 
--     
		if event.object == naverx then

-- ,      

		x:pln (slib.throw.up.generic (slib[uid].accaption () ) )
		

		else

		--       
								
--     , ,      "".

x:pln (slib.throw.object.noprep1 (slib[uid].utilcaption () ) )
x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


		end
	end
	
else 

self:dropdown (event)
-- x:pln (slib.breakfixed.generic ())
--    DROPDOWN

end
end
end
function skaf:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function skaf:do_pres (event)

end
function skaf:open (event)
--      ,       
	
if event.object then
local uid = self.uid
local ouid = event.object.uid
--   ,   
	if event.object == kluch then
	self:openspecial (event)
	else 
	x:p (slib.open.item.novalid1 (slib[uid].accaption () ) )
	x:p " "
	x:p (slib.open.item.novalid2 (slib[ouid].gecaption () ) )
	end
--    ,   

else 

	
	if self.closed then
	
	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			self:chek_inside (event)
				for i = 1, self:count() do
				self.items [ i ].data.hidden = false
				end
			end
			
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end

end
end
function skaf:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function skaf:do_desc (event)
if self.sdvig then
	x:pln (slib.skaf.desc.sdvinut () )
	else
	x:pln (slib.skaf.desc.nesdvinut () )

end

if player.high then

	if self:contains (kluch) then
	x:p "<br>"
	
	x:pln (slib.skaf.kluch.vidno () )
	kluch.data.looked = true

	else
	x:pln (slib.skaf.kluch.sled () )
	
	end
	
	
end

end
function skaf:look2glass (event)
if self.closed then
x:p (slib.skaf.predescontain.closed () )

else
	
x:p (slib.skaf.predescontain.opened () )

end

x:p " "

if self:count () ~= 0 then


	if self:contains (bottle) then
	
	x:pln (slib.skaf.descontain1 () )

	else
	x:pln (slib.skaf.descontain2 () )	
	
	end 


elseif self:count () == 1 then

	
	if self:contains (bottle) then
	
	x:pln (slib.skaf.descontain3 () )
	else
	x:pln (slib.skaf.descontain4 () )
	
	end

	
else 

	x:pln (slib.skaf.descontain5 () )

end
end
function skaf:dropp (event)
if event.object then
	local ouid = event.object.uid
	local uid = self.uid
	
	if event.prep[2] == "in" then
	x:pln (slib.dropp.object.inne.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
--      

	elseif event.prep[2] == "at" then
	x:pln (slib.dropp.object.at.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

--      

	else 
--     
		if event.object == naverx then

-- ,      

		x:pln (slib.dropp.up.generic (slib[uid].accaption () ) )
		

		else

		--       
								
--     , ,      "".

x:pln (slib.dropp.object.noprep1 (slib[uid].utilcaption () ) )
x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


		end
	end
	
else 

self:dropdown (event)

--    DROPDOWN

end
end
skaf.data = {
hasbelow = true,
surface = true,
high = true,
closed = true,
burnable = true,
hasbehind = true,
masc = true,
locked = true,
fixed = true,
prop = true,
container = true,
}skaf:create ('bottle', 'bottle')
function bottle:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function bottle:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function bottle:study (event)
if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
	else

x:pln (slib.study.generic ())
end
end
function bottle:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function bottle:pute (event)
world.put_precheck (self, event )
end
function bottle:eat (event)
x:pln (slib.nonedible.generic ())
end
function bottle:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"
	
	if event.prep[1] == "into" then
	--   


	else
	
	--    
		if self:belongto (skaf) then
			if skaf.closed then
		x:pln (slib.bottle.desc.skaf.closed () )
			else
		x:pln (slib.bottle.desc.skaf.opened () )
			end
		else 
--		x:pln (slib.bottle.desc.elsewhere () )

		end
	
	end
else
x:pln (slib.item.hidden.fromvu () )
end


end
function bottle:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function bottle:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function bottle:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function bottle:do_desc (event)
--        ,      
if self.parent.prop then
x:p ""
else
x:pln (slib.molotok.locdesc.generic ())
end


end
function bottle:take (event)
if self:belongto (skaf) then

	if skaf.closed then
	x:pln (slib.bottle.notake () )
	--     ,  
	else
	world.take_item (self)
	end
elseif self:belongto (player) then
	--      .
	x:pln (slib.bottle.alreadytake () )
else

world.take_item (self)	
end


end
function bottle:burn (event)

end
function bottle:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function bottle:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION

--     LOCKED (   )  FULL     .
--     SURFACE    FULL,   .
--      CHWT   .

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP
end

function bottle:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function bottle:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function bottle:do_pres (event)

end
function bottle:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function bottle:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function bottle:openspecial (event)
x:pln " (   OPEN)      ."
end
function bottle:chek_inside (event)
local uid = self.uid


--   ,      ""


if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:pln (slib.item.inside.one.desc1( slib[uid].utilcaption() ))
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
function bottle:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
bottle.data = {
contained = true,
fem = true,
isin = true,
}skaf:create ('udilo', 'udilo')
function udilo:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function udilo:putdown (event)
self:dropdown (event)
end
function udilo:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function udilo:study (event)
if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
	else

x:pln (slib.study.generic ())
end
end
function udilo:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function udilo:zasun (event)

end
function udilo:pute (event)
world.put_precheck (self, event )
end
function udilo:eat (event)
x:pln (slib.nonedible.generic ())
end
function udilo:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	self:lookbehind (event) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
--	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
--	x:p "<br>LOOKING inside"

	end
else
x:pln (slib.item.hidden.fromvu () )
end


end
function udilo:sdvin (event)

end
function udilo:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function udilo:do_desc (event)
--        ,      
if self.parent.prop then
x:p ""
else
x:pln (slib.molotok.locdesc.generic ())
end


end
function udilo:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function udilo:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function udilo:slozhit (event)

end
function udilo:take (event)
world.take_item (self)

end
function udilo:burn (event)

end
function udilo:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function udilo:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION

--     LOCKED (   )  FULL     .
--     SURFACE    FULL,   .
--      CHWT   .

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP
end

function udilo:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function udilo:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function udilo:do_pres (event)

end
function udilo:chek_inside (event)
local uid = self.uid


--   ,      ""


if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:pln (slib.item.inside.one.desc1( slib[uid].utilcaption() ))
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
function udilo:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function udilo:openspecial (event)
x:pln " (   OPEN)      ."
end
function udilo:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function udilo:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
udilo.data = {
fem = true,
isbehind = true,
}skaf:create ('kluch', 'kluch')
function kluch:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function kluch:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function kluch:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function kluch:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function kluch:eat (event)
x:pln (slib.nonedible.generic ())
end
function kluch:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if self:belongto (skaf) then
		if player.high then
		x:pln (slib.kluch.look.onskaf () )
		--       
		kluch.data.looked = true
		else
			if kluch.looked then
			x:pln (slib.kluch.look.onskaf.high () )
			
			else
			x:pln (slib.item.hidden.fromvu () )
			end

		end
	else
	--  , ,   
	end

else

x:pln (slib.item.hidden.fromvu () )
end


end
function kluch:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function kluch:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function kluch:chek_inside (event)
local uid = self.uid

if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:pln (slib.item.inside.one.desc1( slib[uid].utilcaption() ))
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
function kluch:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function kluch:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function kluch:take (event)
if kluch.looked then
world.take_item (self)
else
x:pln (slib.item.hidden.fromvu () )
end


end
function kluch:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function kluch:do_desc (event)
local uid = self.uid
x:pln (slib[uid].locdesc.generic ())

end
function kluch:pute (event)
world.put_precheck (self, event )
end
function kluch:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
kluch.data = {
opener = true,
ison = true,
masc = true,
}skaf:create ('maska', 'maska')
function maska:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function maska:pute (event)
world.put_precheck (self, event )
end
function maska:take (event)
world.take_item (self)


end
function maska:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	self:lookbehind (event) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
--	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
--	x:p "<br>LOOKING inside"

	end
else
x:pln (slib.item.hidden.fromvu () )
end


end
function maska:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function maska:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
maska.data = {
contained = true,
fem = true,
isin = true,
obscured = true,
}testroom:create ('okno', 'okno')
function okno:do_pres (event)

end
function okno:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function okno:throwe (event)
if not event.target then
local ouid = event.object.uid 
	if event.prep[1] == "at" then
	x:pln (slib.throw.yourself.at (slib[ouid].accaption () ) )
	elseif event.prep[1] == "into" then
	x:pln (slib.throw.yourself.into (slib[ouid].accaption () ) )
	else
	x:pln (slib.throw.yourself.some (slib[ouid].accaption () ) )
	end
	
else 
if event.object then
	local ouid = event.object.uid
	local uid = self.uid
	
	if event.prep[2] == "in" then
	x:pln (slib.throw.object.inne.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
--      

	elseif event.prep[2] == "at" then
	x:pln (slib.throw.object.at.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

--      

	else 
--     
		if event.object == naverx then

-- ,      

		x:pln (slib.throw.up.generic (slib[uid].accaption () ) )
		

		else

		--       
								
--     , ,      "".

x:pln (slib.throw.object.noprep1 (slib[uid].utilcaption () ) )
x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


		end
	end
	
else 

self:dropdown (event)
-- x:pln (slib.breakfixed.generic ())
--    DROPDOWN

end
end
end
function okno:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function okno:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function okno:turnon (event)

end
function okno:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function okno:pute (event)
local ouid = event.object.uid
local tuid = event.target.uid

--      

if self.fixed then

x:pln (slib.put.fixed.generic ())

else


--  ,    

	if not event.object then
		if not event.objects then
		x:pln (slib.put.object.vague ())
		else
		x:pln (slib.put.object.multi ())

		end
			
		

	else

--   

		if event.prep[2] == "on" then

--   "",    ,   

	
			if event.object.surface then

				event.object:chwt (event)
				if event.object.full then

				x:pln (slib.puton.generic.full1 ( slib[tuid].gecaption () ))
				x:pln (slib.puton.generic.full2 ( slib[ouid].caption () ))

				else
				x:pln (slib.puton.generic.from ( slib[tuid].accaption () ))
				x:p (slib.puton.generic.onto ( slib[ouid].gecaption () ))
	
				self:moveto (event.object)
				self.data.onside = true
				end
			else 

			x:pln (slib.puton.generic.nogo.from ( slib[tuid].accaption () ))
			x:p (slib.puton.generic.nogo.onto ( slib[ouid].accaption () ))

				
			end
	


--   "",      ""
		elseif event.prep[2] == "in" then


			if event.object.container then
				if event.object.locked then
					if event.object.fem then 
					x:p (slib.put.whylocked.generic.fem ( slib[ouid].caption () ))
					elseif event.object.masc then 
					x:p (slib.put.whylocked.generic.masc ( slib[ouid].caption () ))			
					elseif event.object.neut then 
					x:p (slib.put.whylocked.generic.neut ( slib[ouid].caption () ))
					end
				else
			
					event.object:chwt (event)
					if event.object.full then

					x:pln (slib.putin.generic.full1 ( slib[tuid].gecaption () ))
					x:pln (slib.putin.generic.full2 ( slib[ouid].caption () ))

					else
					x:pln (slib.putin.generic.from ( slib[tuid].accaption () ))
					x:p (slib.putin.generic.into ( slib[ouid].gecaption () ))
	
					self:moveto (event.object)
					self.data.inside = true
					end
				end
			else 

			x:pln (slib.putin.generic.nogo.from ( slib[tuid].accaption () ))
			x:p (slib.putin.generic.nogo.into ( slib[ouid].accaption () ))

				
			end



--   ,     

		else 
		x:pln (slib.put.noprep.remind (slib[ouid].accaption () ) )
		end
	end		
end
end
function okno:eat (event)
x:pln (slib.nonedible.generic ())
end
function okno:look (event)
if event.prep[1] == "under" then

self:lookunder (event)

elseif event.prep[1] == "behind" then

self:lookbehind (event) 

elseif event.prep[1] == "into" then

self:chek_inside (event)

else 

	local uid = self.uid
		if self.looked then
		x:pln (slib.okno.look.generic () )
		else
		x:pln (slib.okno.look.first () )
		self.data.looked = true
		end 

--         
-- x:pln (slib[uid].look.generic ())

		if self.container then
		
		self:chek_inside (event)

		end		

		if self.surface then

		self:chek_surfac (event)

		end

end	

end
function okno:openspecial (event)
x:pln " (   OPEN)      ."
end
function okno:study (event)
local uid = self.uid

if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
self.data.looked = true
	else

x:pln (slib.study.generic ())
end
end
function okno:chek_surfaccopy (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	end
	
	if self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	end

	
	local surface = slib.surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	inventory = string.sub( inventory, 1, -3 ).."."

	return inventory

end
function okno:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function okno:burn (event)

end
function okno:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function okno:take (event)
local uid = self.uid

if self.fixed then

x:pln (slib.takefixed.generic (slib[uid].accaption () ))	

else
	if self:belongto (karman) then
	x:pln (slib.notake.already (slib[uid].caption ()) )
	else
		
		if self.big then

--  Ш  ,    
			local huid = hands.items[ 1 ].uid	
			if hands:count () ~= 0 then			
			x:pln (slib.hands.full1 (slib[huid].utilcaption() ) )
			x:p (slib.hands.full2 (slib[uid].accaption() ) )
			else
			x:p (slib.hands.takeitem1 (slib[uid].accaption() ) )
			self:moveto (hands)
			end
		else
--  Ĩ  			
		x:p (slib.karman.takeitem1 (slib[uid].accaption() ) )
		self:moveto (karman)
		
		end
	end

end
end
function okno:chek_inside (event)
local uid = self.uid


--   ,      ""

if self.closed then
				

	
else

if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:p (slib.item.inside.one.desc1( slib[uid].precaption() ))
		x:p " "
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
end
function okno:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function okno:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION-PRECAPTION

--     CLOSED    LOCKED (   )   FULL     
--  OBSCURED ,      ,     
--     SURFACE    FULL,     .
--      CHWT   .

--        ,     INSIDE  ONSIDE

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP

-- ,   SLIB
-- (uid).surface.one
-- (uid).inside one

-- (uid).surface.many
-- (uid).inside.many


-- ENTITY -   ,        HIDDEN


end

function okno:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function okno:read (event)

end
function okno:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function okno:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function okno:lookbehind (event)
x:pln "You looked behind the thing."
end
function okno:do_desc (event)
local uid = self.uid
x:p (slib[uid].locdesc.generic ())

if self.hason then
	
world.desc_on (self)
	
end
x:p ". <br>"


end
function okno:sdvin (event)

end
function okno:dropp (event)
if event.object then
	local ouid = event.object.uid
	local uid = self.uid
	
	if event.prep[2] == "in" then
	x:pln (slib.dropp.object.inne.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
--      

	elseif event.prep[2] == "at" then
	x:pln (slib.dropp.object.at.noresult1 (slib[uid].utilcaption () ) )
	x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

--      

	else 
--     
		if event.object == naverx then

-- ,      

		x:pln (slib.dropp.up.generic (slib[uid].accaption () ) )
		

		else

		--       
								
--     , ,      "".

x:pln (slib.dropp.object.noprep1 (slib[uid].utilcaption () ) )
x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


		end
	end
	
else 

self:dropdown (event)

--    DROPDOWN

end
end
okno.data = {
prop = true,
neut = true,
fixed = true,
writable = true,
closed = true,
}testroom:create ('boks', 'boks')
function boks:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function boks:putdown (event)
self:pute (event)
end
function boks:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
			local itemuid = self.items[ 1 ].uid
			if self.items[ 1 ].onside then
			x:p (slib.surface.one.desc1( slib[uid].gecaption() ))
			x:p (slib.surface.one.desc2( slib[itemuid].caption() ))
			end
		
	else

	
	local surface = slib.surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end

end
function boks:study (event)
if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
	else

x:pln (slib.study.generic ())
end
end
function boks:clous (event)
--      ,       

if event.object then
	if event.object.opener or self.opener and event.object  then

	self:lokk (event)

	else 
	end
else
world.container_close (self)	
				
	

end
end
function boks:pute (event)
world.put_precheck (self, event )
end
function boks:eat (event)
x:pln (slib.nonedible.generic ())
end
function boks:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	self:lookbehind (event) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
--	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
--	x:p "<br>LOOKING inside"

	end
else
x:pln (slib.item.hidden.fromvu () )
end

end
function boks:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function boks:handsfull_info (event)

end
function boks:openspecial (event)
local uid = self.uid
local oid = event.object.uid

x:p (slib.openspecial.failed1 (slib[uid].accaption () ) )
x:p " "
x:p (slib.openspecial.failed2 (slib[oid].utilcaption () ) )

end
function boks:take (event)
world.take_item (self)


end
function boks:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function boks:open (event)
local uid = self.uid
if self:belongto (hands) then
-- local items = self.items [ i ]
x:pln (slib.item.putdown.needed (slib[self.uid].accaption () ) )

else
	if event.object then
--      ,       

		if event.object.opener or self.opener and event.object then

		self:openspecial (event)
		end
	else	
--    ,   
		
world.open_container (self)
		
	end
end



end
function boks:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION

--     LOCKED (   )  FULL     .
--     SURFACE    FULL,   .
--      CHWT   .

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP

boks.data.fem = true
end

function boks:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function boks:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function boks:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function boks:do_pres (event)

end
function boks:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function boks:do_desc (event)
local uid = self.uid
x:pln (slib[uid].locdesc.generic ())

end
function boks:burn (event)

end
function boks:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
boks.data = {
dropped = true,
writable = true,
big = true,
burnable = true,
closed = true,
fixed = false,
locked = false,
fem = true,
onside = true,
container = true,
}boks:create ('molotok', 'molotok')
function molotok:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function molotok:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function molotok:study (event)
if not self.looked then

self:look (event)
x:pln (slib.study.generic ())	
	else

x:pln (slib.study.generic ())
end
end
function molotok:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function molotok:pute (event)
world.put_precheck (self, event )
end
function molotok:eat (event)
x:pln (slib.nonedible.generic ())
end
function molotok:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	self:lookbehind (event) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
--	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
--	x:p "<br>LOOKING inside"

	end
else
x:pln (slib.item.hidden.fromvu () )
end


end
function molotok:ask (event)
if self.entity then

x:pln (slib.entity.ask.generic ())

	
	else 
	
x:pln (slib.entity.noask.generic ())

end
end
function molotok:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function molotok:take (event)
world.take_item (self)


end
function molotok:openspecial (event)
x:pln " (   OPEN)      ."
end
function molotok:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function molotok:chek_inside (event)
local uid = self.uid


--   ,      ""


if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:pln (slib.item.inside.one.desc1( slib[uid].utilcaption() ))
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
function molotok:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function molotok:constructor ()
--      PROP      :  FEM-MASC-NEUT, 
--       PROP   FIXED,    .
--  ,   ,    BIG,      ,   .
--          CAPTION-ACCAPTION-GECAPTION-UTILCAPTION

--     LOCKED (   )  FULL     .
--     SURFACE    FULL,   .
--      CHWT   .

--  LOOK      :
--    (GENDESC)
--   Ш   DODESC     PROP
end

function molotok:chwt (event)
--  "" ,        .
--    FULL     
if self:count () <=1 then
self.data.full = false
else
self.data.full = true
end
end
function molotok:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function molotok:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function molotok:do_pres (event)

end
function molotok:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function molotok:do_desc (event)
local uid = self.uid
x:pln (slib[uid].locdesc.generic ())

end
function molotok:burn (event)

end
function molotok:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
molotok.data = {
mobile = true,
masc = true,
contained = true,
inside = true,
hidden = true,
isin = true,
}boks:create ('fork', 'fork')
function fork:brek (event)
if event.object then
--        ,   - -,   

local ouid = event.object.uid
local uid = self.uid
	

	if not stash.brokeattempt then 
	x:pln (slib.brekk.order.reminder () )
	stash.data.brokeattempt = true
	end

--  ,  -      

x:pln (slib.brekk.object.withsomethin1 (slib[uid].accaption () ) )
x:pln (slib.brekk.object.withsomethin2 (slib[ouid].utilcaption () ) )

	
else 
local uid = self.uid

x:pln (slib.breakfixed.generic (slib[uid].accaption () ))
--      
end
end
function fork:chek_surfac (event)
local uid = self.uid
	if self:count () == 0 then
	x:p ""
	
	
	elseif self:count() == 1 then
	
		local itemuid = self.items[ 1 ].uid
		x:pln (slib[uid].surface.one.desc1( slib[uid].gecaption() ))
		x:p (slib[uid].surface.one.desc2( slib[itemuid].caption() ))
		
	else

	
	local surface = slib[uid].surface.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	surface = surface..slib[muid].caption()..", "
	end
	
		
	surface = string.sub( surface, 1, -3 ).."."

	return surface
end
end
function fork:clous (event)
--      ,       
if event.object.opener or self.opener and event.object  then

self:lokk (event)

--    ,   
else 


local items = self.items [ i ]
local uid = self.uid


if self.closed then
	if self.fem then
	x:pln (slib.close.generic.folse.fem (slib[uid].accaption ()))
	elseif self.masc then
	x:pln (slib.close.generic.folse.masc (slib[uid].accaption ()))
	elseif self.neut then
	x:pln (slib.close.generic.folse.neut (slib[uid].accaption ()))
	else 	
	x:pln (slib.gender.problem (slib[uid] () ))
	end

else 
	x:pln (slib.close.generic.tru.fem (slib[uid].accaption ()))

	self.data.closed = true
	items.data.hidden = true

			
end
end
end
function fork:pute (event)
world.put_precheck (self, event )
end
function fork:eat (event)
x:pln (slib.nonedible.generic ())
end
function fork:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	self:lookbehind (event) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
--	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
--	x:p "<br>LOOKING inside"

	end
else
x:pln (slib.item.hidden.fromvu () )
end


end
function fork:touch (event)
local uid = self.uid

x:pln (slib.touch.generic (slib[uid].precaption () ))


end
function fork:take (event)
world.take_item (self)


end
function fork:chek_inside (event)
local uid = self.uid

if self:count () == 0 then

	if self.obscured then

	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))

	else

	--    
				if self.fem then
				x:pln (slib.look.container.empty.fem (slib[uid].caption () ))
				elseif self.masc then
				x:pln (slib.look.container.empty.masc (slib[uid].caption () ))
				elseif self.neut then
				x:pln (slib.look.container.empty.neut (slib[uid].precaption () ))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

	end


elseif self:count() == 1 then
	
	if self.obscured then
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))

	else
		local itemuid = self.items[ 1 ].uid
		x:pln (slib.item.inside.one.desc1( slib[uid].utilcaption() ))
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
	end	
else

	
	local inside = slib.item.inside.many(slib[uid].gecaption ())
	for i = 1, self:count() do
	local muid = self.items[ i ].uid
	inside = inside..slib[muid].caption()..", "
	end
	
		
	inside = string.sub( inside, 1, -3 ).."."

	return inside
end
end
function fork:propcount (event)
local propctr = 0

if obj.prop then propctr = 1 end

for i = 1, obj:count() do
propctr = propctr + propcount (obj.items[i])
end
return propctr


end
function fork:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function fork:lookunder (event)
local uid = self.uid

x:pln (slib.lookunder.generic (slib[uid].accaption () ) )
end
function fork:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function fork:do_desc (event)
local uid = self.uid
x:pln (slib[uid].locdesc.generic ())

end
function fork:open (event)
--      ,       
if event.object.opener or self.opener and event.object then

self:openspecial (event)

--    ,   
else 
	if self.closed then

	local items = self.items [ i ]
	local uid = self.uid
			if self.locked then
				if self.fem then
				x:pln (slib.openlocked.fail.generic.fem (slib[uid].accaption ()))
				elseif self.masc then
				x:pln (slib.openlocked.fail.generic.masc (slib[uid].accaption ()))
				elseif self.neut then
				x:pln (slib.openlocked.fail.generic.neut (slib[uid].accaption ()))
				else 	
				x:pln (slib.gender.problem (slib[uid] () ))
				end

			else
			x:pln (slib.open.generic (slib[uid].accaption ()))
			self.closed = false
			self.locked = false
			items.data.hidden = false
			self:chekinv (event)
			end
	else 
			if self.fem then
			x:pln (slib.open.generic.folse.fem (slib[uid].caption ()))
			elseif self.masc then
			x:pln (slib.open.generic.folse.masc (slib[uid].caption ()))
			elseif self.neut then
			x:pln (slib.open.generic.folse.neut (slib[uid].caption ()))
			else
			x:pln (slib.gender.problem (slib[uid] () ))
			end
end
end
end
function fork:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
fork.data = {
opener = true,
hidden = true,
obscured = true,
mobile = true,
contained = true,
fem = true,
inside = true,
isin = true,
}boks:create ('bell', 'bell')
function bell:dropdown (event)
local uid = self.uid

if self:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	self:moveto (player.parent)
	self.data.dropped = true
	self.data.mobile = true
	
elseif self:belongto (hands) then

	if self.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif self.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif self.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
self:moveto (player.parent)
self.data.dropped = true

else 

x:pln (drop.negative (slib[uid].accaption () ) )

end
end
function bell:do_desc (event)
local uid = self.uid
x:pln (slib[uid].locdesc.generic ())

end
function bell:pute (event)
world.put_precheck (self, event )
end
function bell:take (event)
world.take_item (self)


end
function bell:look (event)
if not self.hidden  then
-- x:p "<i>  look!</i><b>"

	if event.prep[1] == "under" then

	world.lookunder (self)
	
	elseif event.prep[1] == "behind" then

	self:lookbehind (event) 

	elseif event.prep[1] == "into" then

	self:chek_inside (event)

	elseif event.prep[1] == "into" then

	world.lookat (self)
		
	else
	
--	x:p "<br>LOOKING WITHOUT PREP"
	world.lookat (self)
--	x:p "<br>LOOKING inside"

	end
else
x:pln (slib.item.hidden.fromvu () )
end


end
function bell:doing_now (event)
x:p (slib.item.idle.generic () )
x:p " "
end
function bell:dropp (event)
if event.object then
world.throw_at (self, event)
else 
world.dropp (self)
end


end
bell.data = {
mobile = true,
masc = true,
contained = true,
obscured = true,
isin = true,
}testroom:create ('radio', 'radio speaker')
function radio:peek (event)

end
function radio:touch (event)

end
function radio:take (event)

end
function radio:open (event)

end
function radio:turnof (event)

end
function radio:lisn (event)

end
function radio:turnon (event)

end
function radio:brek (event)

end
function radio:sdvin (event)

end
function radio:do_desc (event)
local uid = self.uid
-- x:pln (slib[uid].locdesc.generic ())
if self.hidden then 

	
else 

if self.concealed then
	if self.on then
		if player.drunk then
			local tzpk = math.random (4)
			x:pln (slib.radio.concealed.broadcast () )
			
			if tzpk == 1 then
			x:pln (slib.radio.concealed.broadcast.dtext1 () )
			x:p (slib.radio.concealed.broadcast.dtext2 () )
			x:p (slib.radio.concealed.broadcast.dtext3 () )
			x:p (slib.radio.concealed.broadcast.dtext4 () )
			elseif tzpk == 2 then
			x:pln (slib.radio.concealed.broadcast.dtext3 () )
			x:p (slib.radio.concealed.broadcast.dtext4 () )
			x:p (slib.radio.concealed.broadcast.dtext2 () )
			x:p (slib.radio.concealed.broadcast.dtext1 () )
			
			elseif tzpk == 3 then
			x:pln (slib.radio.concealed.broadcast.dtext2 () )
			x:p (slib.radio.concealed.broadcast.dtext1 () )
			x:p (slib.radio.concealed.broadcast.dtext4 () )
			x:p (slib.radio.concealed.broadcast.dtext3 () )
				
			else 
			x:pln (slib.radio.concealed.broadcast.dtext4 () )
			x:p (slib.radio.concealed.broadcast.dtext3 () )
			x:p (slib.radio.concealed.broadcast.dtext1 () )
			x:p (slib.radio.concealed.broadcast.dtext2 () )
			
			end
		--   ;  ,   
		
		else 
		
			local tzpk = math.random (4)
			x:pln (slib.radio.concealed.broadcast () )
			
			if tzpk == 1 then
			x:pln (slib.radio.concealed.broadcast.text1 () )
			x:p (slib.radio.concealed.broadcast.text2 () )
			x:p (slib.radio.concealed.broadcast.text3 () )
			x:p (slib.radio.concealed.broadcast.text4 () )
			elseif tzpk == 2 then
			x:pln (slib.radio.concealed.broadcast.text3 () )
			x:p (slib.radio.concealed.broadcast.text4 () )
			x:p (slib.radio.concealed.broadcast.text2 () )
			x:p (slib.radio.concealed.broadcast.text1 () )
			
			elseif tzpk == 3 then
			x:pln (slib.radio.concealed.broadcast.text2 () )
			x:p (slib.radio.concealed.broadcast.text1 () )
			x:p (slib.radio.concealed.broadcast.text4 () )
			x:p (slib.radio.concealed.broadcast.text3 () )
				
			else 
			x:pln (slib.radio.concealed.broadcast.text4 () )
			x:p (slib.radio.concealed.broadcast.text3 () )
			x:p (slib.radio.concealed.broadcast.text1 () )
			x:p (slib.radio.concealed.broadcast.text2 () )
			
			end

		end
		
	else 
	
	
	end

elseif self.behindmask then
	
	if self.on then
	
	x:pln (slib.radio.behindmask.working () )
	--   ,  
	x:pln (slib.radio.behindmask.working () )
	else 

	--   ,   
	
	end

else

	if self.on then
	x:pln (slib.radio.opened.working () )

	--    ,  
		
	else 
	
		if stash.radio_checked then
		x:pln (slib.radio.opened.silent.seen () )

		else 
		--     
		x:pln (slib.radio.opened.silent.notseen () )

		stash.data.radio_checked = true
		end
		--   ,  
	
	end


	

end
end

end
function radio:look (event)
if self.hidden then

x:pln (slib.radio.hidden () )
--       \  
	
else 

if self.concealed then
	if self.on then
	x:pln (slib.radio.concealed.working () )
	--  ,  
		
	else 
	
	x:pln (slib.radio.concealed.silent () )
	
	--    
	
	end

elseif self.behindmask then
	
	if self.on then
	
	x:pln (slib.radio.behindmask.working () )
	--   ,  
		
	else 
	x:pln (slib.radio.behindmask.silent () )

	--   ,   
	
	end

else

	if self.on then
	x:pln (slib.radio.opened.working () )

	--    ,  
		
	else 
	
		if stash.radio_checked then
		x:pln (slib.radio.opened.silent.seen () )

		else 
		--     
		x:pln (slib.radio.opened.silent.notseen () )

		stash.data.radio_checked = true
		end
		--   ,  
	
	end


	

end
end
end
function radio:study (event)
self:look (event)
end
function radio:speak (event)

end
radio.data = {
important = true,
concealed = true,
masc = true,
}radio:create ('knob', 'knob')
function knob:touch (event)

end
function knob:sdvin (event)

end
function knob:turnon (event)

end
function knob:look (event)

end
function knob:tuurn (event)

end
function knob:turnof (event)

end
knob.data = {
}world:create ('_funcs', '')
function _funcs:constructor ()
world.reveal_entity = function (obj)
local v = world.entitycount (obj)
local uid = obj.uid

		if v == 0 then

--			x:p (slib.entitycheck.empty () )
			
		elseif v == 1 then
			x:p (slib.entitycheck.single () )
			x:p " "
				for i = 1, obj:count() do
				local item = obj.items[ i ]
					if item.entity then
					local muid = item.uid
					x:p (slib[muid].caption())	
					end
				end
		else
		x:p (slib.entitycheck.mult () )
		x:p " "
local uid = obj.uid
local total_isbehind_count = world.entitycount (obj)
local current_isbehind_count = 0
for i = 1, obj:count() do
local item = obj.items[i]
if item.entity then
local muid = obj.items[ i ].uid
x:p (slib[muid].caption())
current_isbehind_count = current_isbehind_count + 1
if current_isbehind_count < total_isbehind_count - 1 then
x:p ", "
elseif current_isbehind_count == total_isbehind_count - 1 then
x:p "  "
end
end
end
x:p ". "
	end
	end


-- ,     

if v ~= 0 then
x:p "<br>"
for i = 1, player.parent:count() do
local items = player.parent.items [ i ]
if items.entity then
items:do_pres (event)
end
end


else
end
end

_funcs.data = {
}_funcs:create ('_puton', '')
function _puton:constructor ()
world.puton = function (obj, event)

local ouid = event.object.uid
local uid = obj.uid

		if event.object.surface then
		world.put_do (obj, event)
		else
			if event.object == floor then
			world.puton_floor (obj)
--			obj:moveto (player.parent)
			else		
			--  .     __ 
			x:p (slib.puton.nosurface1 (slib[ouid].gecaption () ))
			x:p " "
			--  __,   __   .
			x:p (slib.puton.nosurface2 (slib[uid].accaption () ))
			end
		end
end
end

_puton.data = {
}_funcs:create ('putyes_mobile', '')
function putyes_mobile:constructor ()
world.putyes_mobile = function (obj, event)
local puid = obj.parent.uid
local uid = obj.uid
local ouid = event.object.uid
local prep = event.prep[2]
--				if obj.fem then
--				x:p (slib.putitem.room.fem (slib[uid].accaption () ) )
--				elseif obj.masc then
--				x:p (slib.putitem.room.masc (slib[uid].accaption () ) )
--				else 
--				x:p (slib.putitem.room.neut (slib[uid].accaption () ) )
--				end
						
				-- ,   								
						
				if obj.ison then
				x:p (slib.takeitemon.begin (slib[uid].accaption () ) )
				x:p " "
					if event.object.hardcase then
					x:p (slib.takeitem.from.hardcase (slib[puid].gecaption () ) )
					else
					x:p (slib.takeitem.from.softcase (slib[puid].gecaption () ) )						
					end
				obj.ison = false
				elseif obj.isin then
				x:p (slib.takeitemin.begin (slib[uid].accaption () ) )
				x:p " "
				x:p (slib.takeitem.from.container (slib[puid].gecaption () ) )						
--				x:p " "
--				x:p (slib[ouid].accaption () )
				obj.isin = false
				elseif obj.isunder then 
				x:p (slib.takeitemunder.begin (slib[uid].accaption () ) )
				x:p " "
				x:p (slib.takeitem.fromunder (slib[puid].gecaption () ) )
				x:p " "
--				x:p (slib[ouid].accaption () )
				obj.isunder = false
				elseif obj.isbehind then 
				x:p (slib.takeitembehind.begin (slib[uid].accaption () ) )
				x:p " "
				x:p (slib.takeitem.frombehind (slib[puid].gecaption () ) )
				x:p " "
--				x:p (slib[ouid].accaption () )
				obj.isbehind = false
						
				else
				--- "  ,    "
					if obj.big then
					x:p (slib.takeitem.big (slib[uid].accaption () ) )
					else
					x:p (slib.takeitem.light (slib[uid].accaption () ) )
					end
					
					if obj.fem then
					x:p " "
					x:p (slib.takeitem.kotoro.fem ())
					elseif obj.masc then
					x:p " "
					x:p (slib.takeitem.kotoro.masc ())
					else
					x:p " "
					x:p (slib.takeitem.kotoro.neut ())
					end

					if player.parent.ground then
					x:p " "
					x:p (slib.takeitem.ground1 () )
					else
					x:p " "
					x:p (slib.takeitem.floor1 () )
					end
--				x:p (slib.takeitem.around (slib[uid].accaption ()) )
				
				end
						
				x:p ", "
					
--   \ ------    !!! "", "",   ..
								
				if obj.fem then
				x:p (slib.putitem.room.fin.fem () )
				else 
				x:p (slib.putitem.room.fin.masc ( ) )
				end
-- \\\ ( ""  "" "" "")
	x:p " "
	if prep == "on" then
	x:p (slib.putitem.fin.prepon (slib[ouid].accaption () ) )
	obj.data.ison = true
	obj.data.hidden = false
	x:p ". "
	elseif prep == "in" then
		if event.object.closed then
		--    , (  ).
		x:p (slib.putitem.fin.prepin (slib[ouid].accaption () ) )
		x:p ", "

			if event.object.fem then
			x:p (slib.putitem.contopen.fem () )
		
			elseif event.object.masc then
			x:p (slib.putitem.contopen.masc () )

			else
			x:p (slib.putitem.contopen.neut () )
			
			end
		event.object.data.closed = false
			for i = 1, event.object:count () do
			event.object.items [ i ].data.hidden = false
			event.object.items [ i ].data.obscured = false
			end
		x:p ". "
		else 
		x:p (slib.putitem.fin.prepin (slib[ouid].accaption () ) )
		x:p ". "
		end
	obj.data.isin = true
	obj.data.contained = true
	elseif prep == "under" then
	x:p (slib.putitem.fin.prepunder (slib[ouid].accaption () ) )
	obj.data.isunder = true
	x:p ". "
	elseif prep == "behind" then
	x:p (slib.putitem.fin.prepbehind (slib[ouid].accaption () ) )
	obj.data.isbehind = true
	obj.data.player_put_behind = true
	x:p ". "
	elseif prep == "at" then
	x:p (slib.putitem.fin.prepat (slib[ouid].gecaption () ) )
	obj.data.isat = true
	x:p ". "
	end
						
	

	if event.object.high then
	obj.data.high = true
	else
	obj.data.high = false
	end
	obj:moveto (event.object)
	obj.data.dropped = false
-- 	obj.data.mob = true

						
end
end

putyes_mobile.data = {
}_funcs:create ('putyes_karman', '')
function putyes_karman:constructor ()
world.putyes_karman = function (obj, event)
local uid = obj.uid
local ouid = event.object.uid
local prep = event.prep[2]
-- x:p "  putyes karman"

	if obj.fem then
	x:p (slib.putitem.karman.fem (slib[uid].accaption () ) )
	elseif obj.masc then
	x:p (slib.putitem.karman.masc (slib[uid].accaption () ) )
	else 
	x:p (slib.putitem.karman.neut (slib[uid].accaption () ) )
	end
					
--   \ ------    !!! "", "",   ..
	x:p " "								
	if obj.fem then
	x:p (slib.putitem.room.fin.fem () )
	else 
	x:p (slib.putitem.room.fin.masc () )
	end
-- \\\ ( ""  "" "" "")

	x:p " "
	if prep == "on" then
	x:p (slib.putitem.fin.prepon (slib[ouid].accaption () ) )
	obj.data.ison = true


	elseif prep == "in" then
		if event.object.closed then
		--    , (  ).
		x:p (slib.putitem.fin.prepin (slib[ouid].accaption () ) )
		x:p ", "

			if event.object.fem then
			x:p (slib.putitem.contopen.fem () )
		
			elseif event.object.masc then
			x:p (slib.putitem.contopen.masc () )

			else
			x:p (slib.putitem.contopen.neut () )
			
			end
		x:p ". "

		event.object.data.closed = false
			for i = 1, event.object:count () do
			event.object.items [ i ].data.hidden = false
			event.object.items [ i ].data.obscured = false
			end

		else 
		x:p (slib.putitem.fin.prepin (slib[ouid].accaption () ) )
		x:p ". "
		end
	obj.data.isin = true
	obj.data.contained = true
	elseif prep == "under" then
	x:p (slib.putitem.fin.prepunder (slib[ouid].accaption () ) )
	obj.data.isunder = true
	elseif prep == "behind" then
	x:p (slib.putitem.fin.prepbehind (slib[ouid].accaption () ) )
	obj.data.isbehind = true
	obj.data.player_put_behind = true

	elseif prep == "at" then
	x:p (slib.putitem.fin.prepat (slib[ouid].gecaption () ) )
	obj.data.isat = true
	end
						
	x:p ". "

	if event.object.high then
	obj.data.high = true
	else
	obj.data.high = false
	end
	obj:moveto (event.object)

	-- test!
			
end
end

putyes_karman.data = {
}_funcs:create ('putyes_hands', '')
function putyes_hands:constructor ()
world.putyes_hands = function (obj, event)
local puid = obj.parent.uid
local uid = obj.uid
local ouid = event.object.uid
local prep = event.prep[2]
-- x:pln "  putyes hands"
--  ------    !!! "", "",   ..

	x:p (slib.putitemfrom.hands (slib[uid].accaption () ) )
	x:p " "
			
-- \\\ ( ""  "" "" "")
	if prep == "on" then
	x:p (slib.putitemon.hands2 (slib[ouid].accaption () ) )
	obj.data.ison = true
	obj.data.hidden = false
	elseif prep == "in" then
		if event.object.closed then
		--    , (  ).
		x:p (slib.putitem.fin.prepin (slib[ouid].accaption () ) )
		x:p ", "

			if event.object.fem then
			x:p (slib.putitem.contopen.fem () )
		
			elseif event.object.masc then
			x:p (slib.putitem.contopen.masc () )

			else
			x:p (slib.putitem.contopen.neut () )
			
			end
		x:p ". "

		event.object.data.closed = false
			for i = 1, event.object:count () do
			event.object.items [ i ].data.hidden = false
			event.object.items [ i ].data.obscured = false
			end
		obj.data.isin = true
		else 
		x:p (slib.putitem.fin.prepin (slib[ouid].accaption () ) )
		x:p ". "
		end
	obj.data.isin = true
	elseif prep == "under" then
	x:p (slib.putitemunder.hands2 (slib[ouid].accaption () ) )
	obj.data.isunder = true
	elseif prep == "behind" then
	x:p (slib.putitembehind.hands2 (slib[ouid].accaption () ) )
	obj.data.isbehind = true
	obj.data.player_put_behind = true

	elseif prep == "at" then
	x:p (slib.putitemat.hands2 (slib[ouid].gecaption () ) )
	obj.data.isat = true
	end
					
	x:p "."


		if event.object.high then
		obj.data.high = true
		else
		obj.data.high = false
		end
	obj:moveto (event.object)
	obj.data.dropped = false
			
						
end
end

putyes_hands.data = {
}_funcs:create ('testfunc', '')
function testfunc:constructor ()
world.testfunc = function (obj, event)

local prep = event.prep[2]

x:pln ( prep) 
end
end

testfunc.data = {
}_funcs:create ('desc_on', '')
function desc_on:constructor ()
world.desc_on = function (obj)

local v = world.oncount (obj)
-- x:p ( v )
	if v == 0 then
	return
	else

		if obj.fem then
		x:p (slib.onprop.item.fem () )
		x:p " "
		else
		x:p (slib.onprop.item.masc () )	
		x:p " "
		end

			if v == 1 then
			x:p (slib.onprop.locatt.one () )
			x:p " "
				for i = 1, obj:count() do
				local item = obj.items[ i ]
					if item.ison then
					local muid = item.uid
					x:p (slib[muid].caption())	
					end
				end
		
			else
			x:p (slib.onprop.locatt.mult () )
			x:p " "
local uid = obj.uid
x:p " "
local total_ison_count = world.oncount (obj)
local current_ison_count = 0
for i = 1, obj:count() do
local item = obj.items[i]
if item.ison then
local muid = obj.items[ i ].uid
x:p (slib[muid].caption())
current_ison_count = current_ison_count + 1
if current_ison_count < total_ison_count - 1 then
x:p ", "
elseif current_ison_count == total_ison_count - 1 then
x:p "  "
end
end
end
			end
		
	end
end
end

desc_on.data = {
}_funcs:create ('_putunder', '')
function _putunder:constructor ()
world.putunder = function (obj, event)

local ouid = event.object.uid
local uid = obj.uid
-- world.testfunc (obj, event)
if event.object.hasunder then
		world.put_do (obj, event) 
		else
		--   __   .
		x:p (slib.putunder.nogo (slib[ouid].accaption () ))
		x:p " "
		--  __,   __   .
		x:p (slib.putunder.nogo2 (slib[uid].accaption () ))
		end
end

end

_putunder.data = {
}_funcs:create ('_put_do', '')
function _put_do:constructor ()
world.put_do = function (obj, event)
			
local ouid = event.object.uid
local uid = obj.uid 
if obj.hidden then
x:pln (slib.item.hidden.fromvu () )
else
		if obj:belongto (hands) then

				if event.object.high then
					if player.high then
					--   !!
					world.putyes_hands (obj, event)
	
					else 
					--    ,  "  (, ),    .  ."
					x:p (slib.putno.objecthigh (slib[ouid].caption () ) )						
						
					end
				else 
				--    
					if player.high then
						x:p (slib.putno.objectlow (slib[ouid].caption () ) )	
					
					else
					--   !!
					world.putyes_hands (obj, event)

					end			
				
				end
					
			elseif obj:belongto (karman) then
				if event.object.high then
					if player.high then
					--   !!
					world.putyes_karman (obj, event)
	
					else 
					--    ,  "  (, ),    .  ."
					x:p (slib.putno.objecthigh (slib[ouid].caption () ) )	
												
					end
				else 
				--    
					if player.high then
						x:p (slib.putno.objectlow (slib[ouid].caption () ) )	
					
					else
					world.putyes_karman (obj, event)

					end
				
				end
					
			else
			--     
				local H = hands:count () 
				if  H ~= 0 then
				local kuid = hands.items[ H ].uid
				x:p (slib.player.handsfull (slib[kuid].accaption ()) )

				else 
			if not obj.fixed then

-- ==============================================  "   "
				if event.object.high then
					if player.high then
					world.putyes_mobile (obj, event)
					else 
					--    ,  "  (, ),    .  ."
					x:p (slib.putno.objecthigh (slib[ouid].caption () ) )								
					end
				else 
				--    
					if player.high then
					-- objectlow!!
					x:p (slib.putno.objectlow (slib[ouid].caption () ) )								

					else
					world.putyes_mobile (obj, event)

					end
				
				end
-- ==============================================
					else
					
						if obj.fem then
						x:p (slib.putitemon.notmobile.fem (slib[uid].accaption () ) )
						elseif obj.masc then
						x:p (slib.putitemon.notmobile.masc (slib[uid].accaption () ) )
						else 
						x:p (slib.putitemon.notmobile.neut (slib[uid].accaption () ) )
						end

					
					end
				end
			end

end
end
end

_put_do.data = {
}_funcs:create ('_lookunder', '')
function _lookunder:constructor ()
world.lookunder = function (obj)
local v = world.undercount (obj)
local uid = obj.uid

	if obj.hidden then
	
	x:pln (slib.look.obscured.fem () )
	
	else
	-- ====================================
	if not obj.looked_under then
	x:p (slib.lookunder.first (slib[uid].accaption () ) )
	else
	x:p (slib.lookunder.second (slib[uid].accaption () ) )
	end
--	x:p  ( v )

		if v == 0 then

			if not obj.looked_under then
			x:p (slib.lookunder.nothing.first (slib[uid].accaption () ) )
			else
			x:p (slib.lookunder.nothing.second (slib[uid].accaption () ) )
			end

			
		elseif v == 1 then
--			x:p
			x:p (slib.lookunder.single () )
			x:p " "
				for i = 1, obj:count() do
				local item = obj.items[ i ]
					if item.isunder then
					local muid = item.uid
					x:p (slib[muid].caption())	
					end
				end
		
		else
			x:p (slib.lookunder.mult () )
			x:p " "
local uid = obj.uid
-- x:p (slib.item.inside.many (slib[uid].precaption ()) )
x:p " "
local total_ison_count = world.undercount (obj)
local current_ison_count = 0
for i = 1, obj:count() do
local item = obj.items[i]
if item.isunder then
local muid = obj.items[ i ].uid
x:p (slib[muid].caption())
current_ison_count = current_ison_count + 1
if current_ison_count < total_ison_count - 1 then
x:p ", "
elseif current_ison_count == total_ison_count - 1 then
x:p "  "
end
end
end
x:p ". "
		end
		obj.data.looked_under = true	
	end

			
	
	
	-- ====================================
	

end
end

_lookunder.data = {
}_funcs:create ('_takeitem', '')
function _takeitem:constructor ()
world.take_item = function (obj)
local uid = obj.uid
local pid = obj.parent.uid

if not obj.hidden then
	if obj.fixed then
	x:pln (slib.takefixed.generic (slib[uid].accaption () ))	
	else
		if obj:belongto (karman) then
		x:pln (slib.notake.already (slib[uid].caption ()) )
		elseif obj:belongto (hands) and not obj.isin then 
		x:pln (slib.item.already.inhands (slib[uid].accaption () ) )		
		elseif obj:belongto (hands) and obj.isin then 
						--   ,    ,    
						x:p (slib.item.already.contained.inhands1 (slib[uid].capcaption () ) )				

						if obj.fem then
						x:p (slib.item.already.contained.inhands2.fem (slib[pid].precaption () ) )
						elseif obj.masc then
						x:p (slib.item.already.contained.inhands2.masc (slib[pid].precaption () ) )
						elseif obj.neut then
						x:p (slib.item.already.contained.inhands2.neut (slib[pid].precaption () ) )	
						end
						x:p (slib.item.already.contained.inhands3 (slib[pid].accaption () ) )
	
		else


			if obj.big then
			world.take_big (obj, event)
			else
			world.take_small (obj, event)
			end
		end
	

	end

else
x:pln (slib.item.hidden (slib[uid].gecaption () ) )

end

end
end

_takeitem.data = {
}_funcs:create ('_takefrom', '')
function _takefrom:constructor ()
world.take_from = function (obj)
local uid = obj.uid
local pid = obj.parent.uid
	if obj.ison then
		local tzpt = math.random( 2 )
		if tzpt == 1  then		
		x:p (slib.takefrom.ison (slib[uid].accaption () ))			

			if obj.parent.hardcase then
			x:p "  "
			x:p (slib[pid].gecaption () )
			else 
			x:p "  "
			x:p (slib[pid].gecaption () )
			end

						
		else

			if obj.parent.hardcase then
			x:p (slib.takefrom.ison.hard (slib[pid].gecaption () ) )
			x:p " "
			x:p (slib[uid].accaption () )
			else 
			x:p (slib.takefrom.ison.soft (slib[pid].gecaption () ) )
			x:p " "
			x:p (slib[uid].accaption () )
			end
		
		end						

							
	elseif obj.isin then
		local tzpk = math.random( 2 )
		--   , " %s  ,  "  %s "
	
		if tzpk == 1 then		
			-- "  %s  "
			x:p (slib.takefrom.isin (slib[uid].accaption () ))			
			x:p "  "
			x:p (slib[pid].gecaption () )
				
		else
			-- "   %s "
			x:p (slib.takefrom.isin.ctn (slib[pid].gecaption () ) )
			x:p " "
			x:p (slib[uid].accaption () )		
		end				
	elseif obj.isunder then
		local tzpb = math.random( 2 )
		--   , " %s - ,  " - %s "
	
		if tzpb == 1 then		
			-- "  %s - "
			x:p (slib.takefrom.isunder (slib[uid].accaption () ))			
			x:p " - "
			x:p (slib[pid].gecaption () )
				
		else
			-- "  - %s "
			x:p (slib.takefrom.isunder.ctn (slib[pid].gecaption () ) )
			x:p " "
			x:p (slib[uid].accaption () )		
		end				

	elseif obj.isbehind then
	x:p (slib.takefrom.isbehind (slib[uid].accaption () )	)
	x:p " - "
	x:p (slib[pid].gecaption () )
					
	elseif obj.ishung then
		local tzpt = math.random( 2 )
		--   , " %s  ,  "  %s "
	
		if tzpt == 1 then		
		x:p (slib.takefrom.ishung (slib[uid].accaption () ))			
		-- "  %s  \ "
			if obj.parent.hardcase then
			x:p "  "
			x:p (slib[pid].gecaption () )
			else 
			x:p "  "
			x:p (slib[pid].gecaption () )
			end

							
		else
			-- "   %s "
			if obj.parent.hardcase then
			x:p (slib.takefrom.ishung.hard (slib[pid].gecaption () ) )
			x:p " "
			x:p (slib[uid].accaption () )
			else 
			x:p (slib.takefrom.ison.soft (slib[pid].gecaption () ) )
			x:p " "
			x:p (slib[uid].accaption () ) 
			end
		
		end					
						
						
	elseif obj.dropped then
		
				-- "    \
			
				if obj.fem then
				
					if player.parent.ground then
					x:p (slib.takefrom.ground.fem (slib[uid].accaption () ))
					else
					x:p (slib.takefrom.floor.fem (slib[uid].accaption () ))
					end
				
				elseif obj.masc then
					if player.parent.ground then
					x:p (slib.takefrom.ground.masc (slib[uid].accaption () ))
					else
					x:p (slib.takefrom.floor.masc (slib[uid].accaption () ))
					end
					
				else
					if player.parent.ground then
					x:p (slib.takefrom.ground.neut (slib[uid].accaption () ))
					else
					x:p (slib.takefrom.floor.neut (slib[uid].accaption () ))
					end
				
				
				end
	
	else
	x:p (slib.takeitem.generic (slib[uid].accaption () ))

	end

end
end

_takefrom.data = {
}_funcs:create ('puton_floor', '')
function puton_floor:constructor ()
world.puton_floor = function (obj, event)
local uid = obj.uid
local pauid = player.parent.uid
-- local ouid = event.object.uid
-- local prep = event.prep[2]
x:p "<br>  puton_floor<br>"
	if obj:belongto (karman) then
	-- "    ..."
		if obj.fem then
		x:p (slib.putitem.karman.fem (slib[uid].accaption () ) )
		elseif obj.masc then
		x:p (slib.putitem.karman.masc (slib[uid].accaption () ) )
		else 
		x:p (slib.putitem.karman.neut (slib[uid].accaption () ) )
		end

		-- "  \..."
		x:p " "								
		if obj.fem then
		x:p (slib.putitem.room.fin.fem () )
		else 
		x:p (slib.putitem.room.fin.masc () )
		end

		-- " \ "
		x:p " "
		if player.parent.ground then
		x:p (slib.puton.ground () )
		else
		x:p (slib.puton.floor () )
		end

		x:p ". "
		
		obj:moveto (player.parent)
		obj.data.dropped = true
	
		



	
	elseif obj:belongto (hands) then					
	-- "  ...    , 
	-- ",    ...,     ."
		if obj.fem then
		x:p (slib.putdown.fromhands.fem (slib[uid].accaption () ) )
		elseif obj.masc then
		x:p (slib.putdown.fromhands.masc (slib[uid].accaption () ) )
		else
		x:p (slib.putdown.fromhands (slib[uid].accaption () ) )
		end
		
		-- "  \..."
--		x:p " "								
--		if obj.fem then
--		x:p (slib.putitem.fromhands.fin.fem () )
--		else 
--		x:p (slib.putitem.fromhands.fin.masc () )
--		end

		-- " \ "
		x:p " "
		if player.parent.ground then
		x:p (slib.puton.ground () )
		else
		x:p (slib.puton.floor () )
		end

		x:p ". "
		
		obj:moveto (player.parent)
		obj.data.dropped = true
		obj.data.ison = false
		obj.data.isin = false
		obj.data.isbehind = false
		obj.data.isat = false


	


	elseif obj.dropped then
	x:pln (slib.noputdown.dropped (slib[uid].capcaption () ) )
	
	else
	world.take_from (obj)
		x:p " "
		if obj.fem then
		x:p (slib.putitem.room.fin.fem () )
		else 
		x:p (slib.putitem.room.fin.masc () )
		end

		-- " \ "
		x:p " "
		if player.parent.ground then
		x:p (slib.puton.ground () )
		else
		x:p (slib.puton.floor () )
		end

		x:p ". "
		obj:moveto (player.parent)
		obj.data.dropped = true
		obj.data.ison = false
		obj.data.isin = false
		obj.data.isbehind = false
		obj.data.isat = false

	end
--   \ ------    !!! "", "",   ..
	
end


end

puton_floor.data = {
}_funcs:create ('prop_desc', '')
function prop_desc:constructor ()
world.prop_desc = function (obj, event)

if obj.ison then

elseif obj.isin then

elseif obj.isbehind then

elseif obj.isunder then
	
elseif obj.isat then

end

-- \ \ \  ..
--  .

end
end

prop_desc.data = {
}_funcs:create ('look_at', '')
function look_at:constructor ()
world.lookat = function (obj)
		local uid = obj.uid
		local puid = obj.parent.uid
	
		--!     !
-- 		x:p "  !"
		if obj.isbehind then
			if obj.checked then
			x:p (slib[uid].look.generic ( ))		
			x:p " "
			world.reveal_prep (obj)			
			obj:doing_now ()
			x:p (slib.lookbehind.item (slib[puid].utilcaption () ) )
			x:p ". "
					
				if obj.player_put_behind then
					if obj.fem then
					x:pln (slib.lookbehind.whoputit.fem () )
					else
					x:pln (slib.lookbehind.whoputit.masc () )

					end
				end
			x:p ". <br>"
			else
			x:pln (slib.lookbehind.obscured () )
			x:p "."
			end

		elseif obj.concealed then
		
		x:pln (slib.objekt.concealed () )

		
		else

--  ,     .     DODESC
--		x:p (slib[uid].look.generic ( ))		
		obj:do_desc (event)

-- ,   
	
--       doing_now   ,     ,    

		if obj.ison then
		world.reveal_prep (obj)			
		obj:doing_now ()
			local tupka = math.random( 2 )
				if tupka == 1 then
				x:p (slib.lookon.item1 (slib[puid].precaption () ) )
				x:p ". "
				else
				x:p (slib.lookon.item2 (slib[puid].gecaption () ) )
				x:p ". "				
				end
		elseif obj.isin then
		world.reveal_prep (obj)			
		obj:doing_now ()
			local tupka = math.random( 2 )
				if tupka == 1 then
				x:p (slib.lookin.item1 (slib[puid].precaption () ) )
				x:p ". "
				else
				x:p (slib.lookin.item2 (slib[puid].gecaption () ) )
				x:p ". "				
				end
		
		elseif obj.isbehind then
		if obj.checked then
		world.reveal_prep (obj)			
		obj:doing_now ()
		x:p (slib.lookbehind.item (slib[puid].utilcaption () ) )
		x:p ". "
				
			if obj.player_put_behind then
				if obj.fem then
				x:pln (slib.lookbehind.whoputit.fem () )
				else
				x:pln (slib.lookbehind.whoputit.masc () )

				end
			end
		else
		x:pln (slib.lookbehind.obscured () )

		
		end
		
		elseif obj.isunder then
		world.reveal_prep (obj)			
		obj:doing_now ()
		x:p (slib.lookunder.item (slib[puid].utilcaption () ) )
		x:p ". "
		
		elseif obj.dropped then
		world.reveal_prep (obj)			
		obj:doing_now ()
			if obj.parent.ground then
			x:p " "
			x:p " ."
			else
			x:p " "
			x:p " ."
			end
		
		elseif obj:belongto (hands) then
		world.reveal_prep (obj)			
		x:p " "
		x:p "   ."
				
		else
		
-- 		x:pln " - ,  , . "
		
		
		end


		-- ,   ,     \ .
			if obj.container then
		
				if not obj.closed then
				x:p "<br>"
				world.reveal_container (obj)
				else
				x:p "<br>"

				--     ()
					if obj.fem then
					x:pln (slib.container.sayclosed.fem () )	
					elseif obj.masc then
					x:pln (slib.container.sayclosed.masc () )						
					else
					x:pln (slib.container.sayclosed.neut () )	

					
					end
				
				end
						
			end		

			if obj.hason then
			world.check_on (obj)

			end
		
			if obj.hasunder then

--			world.check_under (obj)
			
			end

	end	
end
end

look_at.data = {
}_funcs:create ('doing_now', '')
function doing_now:constructor ()
world.doing_now = function (obj)
--    , ""  ..,       look_at.

end
end

doing_now.data = {
}_funcs:create ('reveal_prep', '')
function reveal_prep:constructor ()
world.reveal_prep = function (obj)
		local uid = obj.uid
		local puid = obj.parent.uid
		
					if obj.fem then
					x:p " "
					elseif obj.masc then
					x:p " "
					else
					x:p " "
					end
					
	end
end

reveal_prep.data = {
}_funcs:create ('_put_precheck', '')
function _put_precheck:constructor ()
world.put_precheck = function (obj, event)
	
local uid = obj.uid
local puid = obj.parent.uid

if obj.hidden then

x:pln (slib.object.hidden.from.view () )	
	
else
	if event.object then
	local ouid = event.object.uid

		if event.object.hidden then
			if event.object.fem then
			x:pln (slib.event.obj.hidden.fem (slib[ouid].gecaption () ))
			else
			x:pln (slib.event.obj.hidden.masc (slib[ouid].gecaption () ))
			end

		elseif uid == ouid then
			
		x:p (slib.object.selfrecurrence () )

		else
			if event.prep[2] == "on" then
			--      , .

					if ouid == puid and obj.ison then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.already.on (slib[ouid].precaption () ) )
				
					else	
					world.puton (obj, event)
					end
	
			elseif event.prep[2] == "in" then
					if ouid == puid and obj.isin then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.alreadyin (slib[ouid].precaption () ) )
				
					else	
					world.putin (obj, event)
					end
			
			
			-- ,    (hasin?)
			--  ,  ,  closed 
			--     ,  full  
			--   ,  ,  (contained)
			--  , ,    ,      .
	
			elseif event.prep[2] == "under" then
					if ouid == puid and obj.isunder then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.already.under (slib[ouid].utilcaption () ) )				
					else	
					world.putunder (obj, event)
					end

			elseif event.prep[2] == "behind" then
					if ouid == puid and obj.isbehind then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.already.behind (slib[ouid].utilcaption () ) )	
					else	
					world.putbehind (obj, event)
					end
		
			elseif event.prep[2] == "at" then
					if ouid == puid and obj.isat then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.already.at (slib[ouid].utilcaption () ) )	
					else	
					world.putat (obj, event)
					end

			else 
					if ouid == puid and obj.ison then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.already.on (slib[ouid].utilcaption () ) )	
					elseif ouid == puid and obj.isin then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.alreadyin (slib[ouid].utilcaption () ) )	
					elseif ouid == puid and obj.isat then
					x:p (slib.item.already.there (slib[uid].caption () ) )
					x:p " "
					x:p (slib.item.already.at (slib[ouid].precaption () ) )	
					else

						if event.object.hasin and not event.object.closed then
						world.put_in (obj, event)
						elseif event.object.hason then
						world.puton (obj, event)
					 	end
					end
			
			end
		end
			
	else	
-- put without object
--        ,  
world.puton_floor (obj, event)

	
	
	end
end
end
end

_put_precheck.data = {
}_funcs:create ('_take_all', '')
function _take_all:constructor ()
world.take_all = function (event, obj)

if obj.hidden then return end 
if obj.mobile and not obj.big then
--       
local mobct = world.mobcount (obj)

if mobct == 1 then

world.mobdesc (obj)  end 
for i = 1, player.parent:count() do 
local item = player.parent.items[ i ] 
world.mobdesc_rec (item) 
end

end

end
end

_take_all.data = {
}_funcs:create ('_check_on', '')
function _check_on:constructor ()
world.check_on = function (obj)
-- x:pln "CHECK ON initiated!<br>"
local uid = obj.uid
local C = world.oncount (obj)

if C == 1 then
--  ,   

	if obj.obscured then 
	-- " \ - ,    , ."
	x:pln (slib.look.checkon.nonempty.obscured (slib[uid].precaption () ))
	else

	local itemuid = obj.items[ C ].uid
	x:p (slib.item.onside.one.desc1( slib[uid].precaption() ))
	x:p " "
	x:p (slib.item.onside.one.desc2( slib[itemuid].caption() ))




	end

elseif C == 0 then
--  , ,     
	if obj.obscured then
	x:pln (slib.look.checkon.empty.obscured (slib[uid].precaption () ))
	else
	x:pln (slib.look.checkon.empty.util (slib[uid].precaption () ))

	end	

else
-- !  -       !
--   " (uid)   -  -."
world.checkon_multiple (obj)

end

end

			


world.checkon_oneitem = function (obj)
		for i = 1, obj:count () do
		local itemuid = obj.items[ i ].uid
		local uid = obj.uid
			if itemuid.ison then
			x:p (slib.item.onside.one.desc1( slib[uid].precaption() ))
			x:p " "
			x:p (slib.item.onside.one.desc2( slib[itemuid].caption() ))
			end
		end
end

world.checkon_multiple = function (obj)
	local uid = obj.uid
	x:p (slib.item.onside.many (slib[uid].precaption ()) )
	x:p " "
	local N = obj:count()
	local V = N - 1
-- uid  
	local vuid = obj.items[ V ].uid
	local lastuid = obj.items[ N ].uid

		for i = 1, N - 2 do
		local muid = obj.items[ i ].uid
			if muid.ison then
			x:p (slib[muid].caption())
			x:p ", "
	
			end
		end
	x:p (slib[vuid].caption() )
	x:p "  "
	x:p (slib[lastuid].caption() )
	x:p "."

	end

end

_check_on.data = {
}_funcs:create ('_look_loc', '')
_look_loc.data = {
}_funcs:create ('_do_dropped', '')
function _do_dropped:constructor ()
world.do_dropped = function (obj)

x:p "<br>"
local dropctr = world.dropcount (obj)
local uid = obj.uid

if dropctr == 0 then
--	x:p ""

  --  ,     
elseif dropctr == 1 then

        local itemuid  --     uid ,    
        for i = 1, obj:count() do
           local item = obj.items[ i ]
           if item.dropped then
                itemuid = item.uid  --    
	break  --   ,              !
           end
       end
		if obj.floor then
		x:pln (slib.floor.one ( slib[itemuid].caption ()))
		
		elseif self.ground then
		x:pln (slib.ground.one ( slib[itemuid].caption ()))
			
		elseif self.water then 
		x:pln (slib.water.one ( slib[itemuid].caption ()))

		
		end

else

	if obj.floor then
	local dropitems = slib.floor.many()
	elseif obj.ground then
	local dropitems = slib.ground.many()
	else
	local dropitems = slib.water.many()
	end

for i = 1, obj:count() do
	local item = obj.items[ i ] 
	if item.dropped then
		local itemuid = obj.items[ i ].uid
		dropitems = dropitems..slib[itemuid].caption()..", "
	end
end

dropitems = string.sub( dropitems, 1, -3 ).."."

return dropitems

end
end
end

_do_dropped.data = {
}_funcs:create ('_dropp_obj', '')
function _dropp_obj:constructor ()
world.dropp = function (obj)
local uid = obj.uid

if obj:belongto (karman) then
	
	x:pln (slib.dropdown.fromkarman (slib[uid].accaption () ) )
	obj:moveto (player.parent)
	obj.data.dropped = true
	
elseif obj:belongto (hands) then

	if obj.fem then
	x:pln (slib.dropdown.fromhands.fem (slib[uid].accaption () ) )
	elseif obj.masc then
	x:pln (slib.dropdown.fromhands.masc (slib[uid].accaption () ) )
	elseif obj.neut then
	x:pln (slib.dropdown.fromhands.neut (slib[uid].accaption () ) )
	else
	x:pln (slib.dropdown.fromhands (slib[uid].accaption () ) )
	end
obj:moveto (player.parent)
obj.data.dropped = true
else 

x:pln (slib.drop.negative (slib[uid].accaption () ) )
end
end


-- ================================== DROP AT OBJECT GENERIC
world.throw_at = function (event, obj)
		local ouid = event.object.uid
		local uid = obj.uid
	
			if event.prep[2] == "in" then
			x:pln (slib.throw.object.inne.noresult1 (slib[uid].utilcaption () ) )
			x:p (slib.throw.object.inne.noresult2 (slib[ouid].accaption () ) )
			--        ,    

			elseif event.prep[2] == "at" then
			x:pln (slib.throw.object.at.noresult1 (slib[uid].utilcaption () ) )
			x:p (slib.throw.object.at.noresult2 (slib[ouid].accaption () ) )

			--      

			else 
			--     
				if event.object == naverx then

				-- ,      

				x:pln (slib.throw.up.generic (slib[uid].accaption () ) )
		

				else

				--       
								
				--     , ,      "".

				x:pln (slib.throw.object.noprep1 (slib[uid].utilcaption () ) )
				x:pln (slib.throw.object.noprep2 (slib[ouid].accaption () ) )


				end
			end
end

end

_dropp_obj.data = {
}_funcs:create ('take_big', '')
function take_big:constructor ()
world.take_big = function (obj, event)

				if hands:count () ~= 0 then	

					for i = 1, hands:count () do
					local huid = hands.items[ 1 ].uid	

 					x:pln (slib.hands.full1 (slib[huid].utilcaption() ) )
					x:p (slib.hands.full2 (slib[uid].accaption() ) )
					end
				else
 
 				-- 
				world.take_from (obj, event)
		
					if obj.fem then
					x:p (slib.hands.take.fembak () )
					elseif obj.masc then
					x:p (slib.hands.take.mascbak () )
					else
					x:p (slib.hands.take.neutbak () )
					end

				obj:moveto (hands)
				hands.data.full = true
				obj.data.dropped = false
				obj.data.isin =false
				obj.data.ison = false
				obj.data.isunder = false
				obj.data.isbehind = false
				obj.data.ishung = false
			
								
				end


end

end

take_big.data = {
}_funcs:create ('take_small', '')
function take_small:constructor ()
world.take_small = function (obj, event)

--  "  ", "-",  

	world.take_from (obj)
	x:p " "
	x:p (slib.karman.takeitem2 () )
			obj:moveto (karman)
			obj.data.dropped = false
			obj.data.isin =false
			obj.data.ison = false
			obj.data.isunder = false
			obj.data.isbehind = false
			obj.data.ishung = false

end
end

take_small.data = {
}_funcs:create ('_check_under', '')
function _check_under:constructor ()
world.check_under = function (obj)
local v = world.undercount (self)

--   , - 
	--         -   (under_known),  ,  "- ".

		if not obj.looked_under then
			if v ~= 0 then
			x:p (slib.somethin.under (slib[uid].utilcaption () ) )
			end
		else
		world.lookunder (obj)
				
		end


end
end

_check_under.data = {
}_funcs:create ('_putin', '')
function _putin:constructor ()
world.putin = function (obj, event)
local ouid = event.object.uid
local uid = obj.uid

		if event.object.container then
			if event.object.hidden then
			x:pln (slib.putin.object_hidden (slib[uid].accaption () ) )

			-- ,      ,    .
			--     ,      .
						
			else 
				if event.object.locked then
					if event.object.fem then
					x:pln (slib.putin.object_locked.fem (slib[ouid].capcaption () ) )
					elseif event.object.masc then
					x:pln (slib.putin.object_locked.masc (slib[ouid].capcaption () ) )
					else
					x:pln (slib.putin.object_locked.neut (slib[ouid].capcaption () ) )					
					end
							
				else
					if obj.big and not event.object.big then
						if event.object.fem then
						x:pln (slib.putin.object_toobig.fem (slib[ouid].capcaption () ) )
						x:p ", "
						x:pln (slib.putin.object_toobig.fin.fem (slib[uid].caption () ) )

						elseif event.object.masc then
						x:pln (slib.putin.object_toobig.masc (slib[ouid].capcaption () ) )
						x:p ", "
						x:pln (slib.putin.object_toobig.fin.neut (slib[uid].caption () ) )

						else
						x:pln (slib.putin.object_toobig.neut (slib[ouid].capcaption () ) )					
						x:p ", "
						x:pln (slib.putin.object_toobig.fin.neut (slib[uid].caption () ) )

						end

					else
					world.put_do (obj, event)
					end
					
				end
			end
		else
		
			--     
			x:p (slib.putin.negate1 (slib[uid].caption () ))
			x:p " "
			--  ,  __  .
			x:p (slib.putin.negate2 (slib[ouid].accaption () ))
			
		end

end
end

_putin.data = {
}_funcs:create ('_reveal_container', '')
function _reveal_container:constructor ()
world.reveal_container = function (obj)
-- x:pln "Reveal container initiated!<br>"
local uid = obj.uid
local containct = world.containcount (obj)

if containct == 1 then
--  ,   

	if obj.obscured then 
	x:pln (slib.look.container.nonempty.obscured (slib[uid].precaption () ))
	else
	world.container_oneitem (obj)		

	end

elseif containct == 0 then
--  , ,     
	if obj.obscured then
	x:pln (slib.look.container.empty.obscured (slib[uid].precaption () ))
world.container_empty (obj)
	else
	end	

else
-- !  -       !
--   " (uid)   -  -."
world.container_multiple (obj)

end


end

-- ==========================================

world.container_multiple = function (obj)
-- x:pln "CONTAINER MULTIPLE INITIATED"
	local uid = obj.uid
	x:p (slib.item.inside.many (slib[uid].precaption ()) )
	x:p " "
	local N = obj:count()
	local V = N - 1
-- uid  
	local vuid = obj.items[ V ].uid
	local lastuid = obj.items[ N ].uid
		
		for i = 1, N - 2 do
		local muid = obj.items[ i ].uid
		x:p (slib[muid].caption())
		x:p ", "
		end
	x:p (slib[vuid].caption() )
	x:p "  "
	x:p (slib[lastuid].caption() )
	x:p "."

	end



world.container_oneitem = function (obj)
-- x:pln "<b>Container ONE ITEM initiated</b><br>"
		for i = 1, obj:count () do
		local itemuid = obj.items[ i ].uid
		local uid = obj.uid
		x:p (slib.item.inside.one.desc1( slib[uid].precaption() ))
		x:p " "
		x:p (slib.item.inside.one.desc2( slib[itemuid].caption() ))
		end
end


end

_reveal_container.data = {
}_funcs:create ('_lookbehind', '')
function _lookbehind:constructor ()
world.lookbehind = function (obj)
local v = world.behindcount (obj)
local uid = obj.uid

	if obj.hidden then
	
	x:pln (slib.look.obscured.fem () )
	
	else
	-- ====================================
	x:p (slib.lookbehind.first (slib[uid].accaption () ) )

--	x:p  ( v )

		if v == 0 then

			x:p (slib.lookbehind.empty (slib[uid].accaption () ) )
			
		elseif v == 1 then
--			x:p
			x:p (slib.lookbehind.single () )
			x:p " "
				for i = 1, obj:count() do
				local item = obj.items[ i ]
					if item.isbehind then
					local muid = item.uid
					x:p (slib[muid].caption())	
					end
				end
	for i = 1, obj:count() do
		if obj.items[ i ].isbehind then
		obj.items[ i ].data.checked = true
		end
	end
		else
			x:p (slib.lookunder.mult () )
			x:p " "
local uid = obj.uid
-- x:p (slib.item.inside.many (slib[uid].precaption ()) )
x:p " "
local total_isbehind_count = world.behindcount (obj)
local current_isbehind_count = 0
for i = 1, obj:count() do
local item = obj.items[i]
if item.isbehind then
local muid = obj.items[ i ].uid
x:p (slib[muid].caption())
current_isbehind_count = current_isbehind_count + 1
if current_isbehind_count < total_isbehind_count - 1 then
x:p ", "
elseif current_isbehind_count == total_isbehind_count - 1 then
x:p "  "
end
end
end
x:p ". "
	for i = 1, obj:count() do
		if obj.items[ i ].isbehind then
		obj.items[ i ].data.checked = true
		obj.items[ i ].data.looked = true
		
		end
	end
		end
		obj.data.looked_behind = true	
	end



	
	
	-- ====================================
	


end
end

_lookbehind.data = {
}_funcs:create ('_putbehind', '')
function _putbehind:constructor ()
world.putbehind = function (obj, event)

local ouid = event.object.uid
local uid = obj.uid
-- world.testfunc (obj, event)
if event.object.hasbehind then

		if world.behindcount (event.object) >= 4 then
			local tzpko = math.random (2)
			if tzpko == 1 then
			x:pln (slib.putbehind.toomuch.one (slib[ouid].accaption () ) )	
			else
			x:pln (slib.putbehind.toomuch.two (slib[ouid].utilcaption () ) )	
				
			end
		else
		world.put_noheight (obj, event) 
		end
else
x:p (slib.putbehind.nogo (slib[ouid].accaption () ))
end
end
end

_putbehind.data = {
}_funcs:create ('_put_no_height', '')
function _put_no_height:constructor ()
world.put_noheight = function (obj, event)
			
local ouid = event.object.uid
local uid = obj.uid 
if obj.hidden then
x:pln (slib.item.hidden.fromvu () )
else
		if obj:belongto (hands) then

		world.putyes_hands (obj, event)
	
	
		elseif obj:belongto (karman) then
		world.putyes_karman (obj, event)
		
					
		else
				local H = hands:count () 
				if  H ~= 0 then
				local kuid = hands.items[ H ].uid
				x:p (slib.player.handsfull (slib[kuid].accaption ()) )

				else 
					if not obj.fixed then

					world.putyes_mobile (obj, event)
					else
					
						if obj.fem then
						x:p (slib.putitemon.notmobile.fem (slib[uid].accaption () ) )
						elseif obj.masc then
						x:p (slib.putitemon.notmobile.masc (slib[uid].accaption () ) )
						else 
						x:p (slib.putitemon.notmobile.neut (slib[uid].accaption () ) )
						end

					
					end
				end
			end

end
end

end

_put_no_height.data = {
}world:constructor ()
player:constructor ()
_all:constructor ()
stash:constructor ()
testroom:constructor ()
stol:constructor ()
skaf:constructor ()
bottle:constructor ()
udilo:constructor ()
okno:constructor ()
boks:constructor ()
molotok:constructor ()
_funcs:constructor ()
_puton:constructor ()
putyes_mobile:constructor ()
putyes_karman:constructor ()
putyes_hands:constructor ()
testfunc:constructor ()
desc_on:constructor ()
_putunder:constructor ()
_put_do:constructor ()
_lookunder:constructor ()
_takeitem:constructor ()
_takefrom:constructor ()
puton_floor:constructor ()
prop_desc:constructor ()
look_at:constructor ()
doing_now:constructor ()
reveal_prep:constructor ()
_put_precheck:constructor ()
_take_all:constructor ()
_check_on:constructor ()
_do_dropped:constructor ()
_dropp_obj:constructor ()
take_big:constructor ()
take_small:constructor ()
_check_under:constructor ()
_putin:constructor ()
_reveal_container:constructor ()
_lookbehind:constructor ()
_putbehind:constructor ()
_put_no_height:constructor ()
PARSE_ERROR = {[[      .]],[[    .]],[[,     .]],[[   "".]],[[    .]],[[    .]],[[     .  .]],[[,      .]],[[ - .]],}